
#site{
    background:#EEEEEE;
}

p{
    color:black;
}

button, input[type="submit"]{
    border:2px outset #04ba74;
    background:white;
    padding:5px;
    border-radius:5px;
}

:focus{
    outline:none;
}


.workflow-create-wrapper{
    font-family:sans-serif;
    width:100%;
    height:100%;
    background:white;
    padding-top:50px;
    padding-left:40px;
    box-sizing: border-box;
}

#create{
    height: 100%;
}

.workflow-create-wrapper p label, .workflow-create-wrapper p input, .workflow-create-wrapper p textarea{
    vertical-align:top;
    display:block;
}

.workflow-create-wrapper p input, .workflow-create-wrapper p textarea{
    width:400px;
    resize:none;
    margin-top:4px;
    margin-bottom:10px;
}

.workflow-wrapper{
    white-space:nowrap;
    text-align:left;
    width: -moz-fit-content;
    width: fit-content;
    background: white;
    padding: 50px;
    padding-top: 35px;
    min-width: 100%;
    min-height: 100%;
    box-sizing: border-box;
}

.workflow-wrapper.printing{
    margin-top:0px;
    background:white;
}

.project-title-in-workflow{
    font-size: 12px;
    text-decoration: underline;
    color: #444444;    
}

#content-container{
    font-family:'Open Sans';
}

.workflow-container{
    font-family:'Open Sans';
    position:relative;
    background:white;
    overflow:visible;
    margin:10px;
    padding:0px;
    -webkit-user-select:none;
            user-select:none;
}

.printing .workflow-container{
    margin-right:10px;
}

.workflow-header{
    margin:20px;
    margin-top:50px;
    border-radius:10px;
}

.workflow-header > div{
    margin-left:20px;
}

.parent-workflow-indicators{
    background:white;
    border-radius: 10px;
    padding-right:10px;
    padding-left:10px;
    margin-bottom:8px;
}

.emptytext{
    white-space:normal;
    max-width:800px;
}

.workflow-view-select{
    display:flex;
    gap: 5px;
    flex-wrap:wrap;
    margin:0px 0px 10px 0px;
}

.workflow-view-select > *{
    max-width:200px;
    overflow:hidden;
    padding:8px; 
    font-size:16px;
    border-radius:20px;
    background:white;
    border:1px solid #E9EBF2;
}

.title-text ul, .title-text ol{
    padding-left: 1.5em;
}

.ql-editor ul li, .ql-editor ol li{
    padding-left: 0 !important;
}

.workflow-view-select .title-text{
    white-space: nowrap;
}

.workflow-view-select .active{
    background:#04ba74;
    color:white;
    border:1px solid #04ba74;
}

.workflow-view-select .disabled{
    background:#E9EBF2;
    color:darkgrey;
    pointer-events: none;    
}

.other-views{
    position:relative;
    overflow:visible;
}

.views-dropdown{
    display:none;
    z-index:5;
    background:white;
    position:absolute;
    padding:10px;
    border-radius:5px;
    box-shadow: 0px 2px 2px 0px rgba(0,0,0,0.3);
    margin-top:5px;
    margin-left:-5px;
}

.views-dropdown a{
    display:block;
    margin:2px;
}

.views-dropdown.toggled{
    display:block;
}

.workflow-details{
    /*padding:50px;*/
    width: -moz-fit-content;
    width: fit-content;
}
/*
.workflow-details .workflow-for-menu{
    color:black;
    margin-left:10px;
    border-color:black;
    margin-bottom:30px;
}
*/
.workflow-wrapper *:is(.node,.week,.column,.workflow-for-menu,.outcome):not(.selected):not(.valid-drop):hover{
    border-color:gray;
}


.workflow-details .workflow-for-menu.selected{
    background:white;
    color:black;
}

.week{
    background:#f5f5f5;
    min-height:100px;
    padding:10px;
    padding-bottom:24px;
    margin-top:5px;
    box-sizing:border-box;
    border:2px solid white;
    border-radius:5px;
    position:relative;
}

.week > .title-text{
    font-weight:600;
    font-size:14px;
    white-space: normal;
    overflow: hidden;
}

.week-workflow.dragging{
    height:50px;
    overflow:hidden;
    border-width:2px;
    border-radius:5px;
}

.week-workflow.dragging .week{
    border:none;
}

.week-workflow.dragging .node-block{
    display:none;
}


.week-block{
    width:100%;
    padding-left:10px;
    padding-right:10px;
    box-sizing:border-box;
}


.week-block > div:nth-of-type(odd) > .week{
    background: #e0e0e0e0;
}

.week.strategy{
    border:black double;
    margin-left:-1px;
}

.strategy-tab > div{
    display:inline-block;
    vertical-align:top;
    box-sizing:border-box;
}

.strategy-tab  .strategy-tab-square{
    background:#660385;
    padding:4px;
    height:48px;
}

.strategy-tab-triangle{
    width:0;
    height:0px;
    border-top:24px solid transparent;
    border-bottom:24px solid transparent;
    border-right:16px solid #660385;
}

.strategy-tab-circle{
    background:white;
    border-radius:20px;
    width:40px;
    height:40px;
    text-align:center;
}

.strategy-tab{
    position:absolute;
    right:-48px;
    top:calc(50% - 24px);
}

.strategy-tab img{
    width:24px;
    margin-top:calc(50% - 12px);
}

.column-workflow{
    display:inline-block;
    vertical-align:top;
}

.column{
    position:relative;
    padding:5px;
    width:160px;
    white-space: normal;
    text-align:center;
    vertical-align:top;
    box-sizing:border-box;
    border:2px solid white;
    border-radius:5px;
}

.column-line div{
    display:inline-block;
    vertical-align: middle;
    width:calc(100% - 32px);
    padding:2px;
    box-sizing:border-box;
    white-space: normal;
}

.column-line img{
    display:inline-block;
    width:32px;
    vertical-align: middle;
    padding:2px;
    box-sizing:border-box;
}

.column-line .material-symbols-rounded{
    font-size: 32px;
    font-weight: 300;
    vertical-align: middle;
    display: inline-block;
    padding: 2px;
    box-sizing: border-box;
}

.column-line{
    min-height:32px;
    white-space: nowrap;
}

.column-row{
    padding-left:40px;
    padding-right:40px;
    background:white;
    position:sticky;
    top:0px;
    z-index:2;
    font-size:16px;
    border:2px solid white;
    display: flex;
}

.condensed .column-row{
    gap: 60px;
    padding-left: 50px;
    padding-right: 50px;
}

.node-week:first-child {
    padding-top: 5px;
}

.node-week{
    width:100%;
    display:block;
    position:relative;
    min-height:50px;
    padding-top:30px;
}

.node-week.empty{
    min-height:0px;
    padding-top:0px;
}

.node-week.dragging.ui-sortable-helper .node{
    position:static;
}

.node-block{
    min-height:100px;
}

.node-block.term{
    /*width:160px;*/
    width: 220px;
    display:inline-block;
    vertical-align: top;
}

.term .node{
    left:10px !important;
    width:180px;
}


.node-ghost{
    width:160px;
    min-height:50px;
    border:1px dashed black;
    position:absolute;
    cursor:move;
}

.nodeweek-ghost{
    width:160px;
    min-height:50px;
    border:1px dashed black;
    position:absolute;
    cursor:move;
}

.columnworkflow-ghost{
    width:160px;
    min-height:50px;
    border:1px dashed black;
    position:absolute;
    z-index:3;
    cursor:move;
}

.weekworkflow-ghost{
    min-height:50px;
    border:1px dashed black;
    position:absolute;
    cursor:move;
}

.outcomeoutcome-ghost{
    min-width:300px;
    min-height:10px;
    border:1px dashed black;
    position:absolute;
    cursor:move;
}

.outcomeworkflow-ghost{
    min-width:300px;
    min-height:10px;
    border:1px dashed black;
    position:absolute;
    cursor:move;
}

.node{
    width:200px;
    border:solid 1px black;
    position:relative;
    white-space:normal;
    border-radius:5px;
}

.node-top-row{
    padding:5px;
    box-sizing:border-box;
    background:white;
    margin-top:5px;
    width:100%;
    display: flex;
    align-items: center;
    gap: 5px;
}

.node-icon img{
    width:24px;
    vertical-align:middle;
}


.node.program .node-icon{
    width:0;
}

.node-title{
    overflow-x:hidden;
    text-align: center;
    min-height:20px;
    font-weight:600;
    box-sizing:border-box;
    font-size:12px;
    vertical-align:middle;
    flex-grow: 1;
}

.node.program .node-title{
    width:100%;
    text-align: left;
}

.node .assignment-timing{
    background: white;
}

.assignment-timing{
    padding: 5px;
    box-sizing: border-box;
    width: 100%;
    display: flex;
    gap: 5px;
}

.assignment-timing .flatpickr-input+input{
    font-size: 12px;
}

.assignment-in-node .assignment-timing{
    flex-wrap: wrap;
}

.assignment-in-node .workflow-title{
    font-size: 12px;
}

.flatpickr-input+input:disabled{
    background: none;
    border: none;
    color: #444444;
}

.assignment.node{
    width: 600px
}

.linked-workflow.link-noaccess{
    color: "#444444";
}

.linked-workflow{
    background:white;
    width:100%;
    font-size:12px;
    box-sizing:border-box;
}

.linked-workflow.hover-shade{
    color:#1976bc;
}

.linked-workflow > *{
    display:inline-block;
    vertical-align:middle;
}

.linked-workflow > img{
    padding-right:5px;
    padding-left:5px;
    width:12px;
}

.node-details{
    width:100%;
    background:white;
    display:none;
    padding:5px;
    font-size:12px;
    box-sizing:border-box;
}

.node-details default-text{
    font-style:italic;
    color:grey;
}

.node.dropped .node-details{
    display:block
}

.node-drop-row{
    width:100%;
    height:20px;
    background:white;
    border-radius:0 0 5px 5px;
    overflow:hidden;
    cursor:pointer;
}


.week > .node-block{
    display:none;
}

.week.dropped > .node-block{
    display:block;
}

.week-drop-row{
    position:absolute;
    bottom:0px;
    left:0px;
    width:100%;
    height:20px;
    border-radius:0 0 5px 5px;
    overflow:hidden;
    cursor:pointer;
}

.node-drop-side{
    display:inline-block;
    vertical-align: middle;
    height:100%;
    width:40%;
    box-sizing:border-box;
}

.node-drop-left{
    font-size:14px;
    font-weight:600;
    padding-left: 3px;
}

.node-drop-right{
    line-height:100%;
    text-align:right;
    white-space:nowrap;
}

.node-drop-time{
    height:100%;
    font-size:12px;
    text-align:right;
    display:inline-block;
    padding-right:3px;
}

.node-drop-middle{
    display:inline-block;
    vertical-align: middle;
    text-align:center;
    width:20%;
    height:100%;
}

.node-drop-row img,.week-drop-row img{
    width:12px;
    vertical-align:middle;
    display:inline-block;
}

.outcome{
    position:relative;
    margin-left:20px;
    border:2px solid white;
    padding:2px;
    min-width:300px;
    max-width:800px;
}

li.outcome-outcome::before{
    content:"";
    display:block;
    width:10px;
    height:0;
    border-top:2px solid #04ba74;
    margin-top:-2px;
    position:absolute;
    top:15px;
    left:-12px;
}

li.outcome-outcome{
    position:relative;
    margin-left:12px;
    list-style-type:none;
}

li.outcome-outcome > .outcome{
    margin-left:0px;
}

li.outcome-outcome::marker{
    
}

ol.children-block{
    padding-left:0px;
}

.outcome ol ol{
    list-style-type:lower-roman;
}

.outcome.dropped > .outcome-create-child{
    display:block;
}

.outcome.dropped > .children-block:empty + .outcome-create-child{
    display:none;
}

.outcome-create-child{
    position:relative;
    font-size:12px;
    color:#04ba74;
    margin-left:40px;
    display:none;
    cursor:pointer;
}

.outcome-create-child::before{
    content:"";
    display:block;
    width:10px;
    height:6px;
    border-bottom:2px solid #04ba74;
    border-left:2px solid #04ba74;
    position:absolute;
    top:0px;
    left:-20px;
}

.outcome-title{
    padding:2px;
    white-space:normal;
}

.children-block{
    border-left:2px solid #04ba74;
    margin-left:20px;
    margin-top:0px;
    margin-bottom:0px;
    display:none;
    position:relative;
}


.outcome.dropped > .children-block{
    display:block;
}

.outcome-drop{
    margin-left:14px;
    line-height:12px;
    cursor:pointer;
}

.outcome-drop-img{
    display:inline-block;
}

.outcome-drop-text{
    font-size:10px;
    color:#04ba74;
    display:inline-block;
    margin-left:10px;
    vertical-align:top;
}

.outcome-drop-img img{
    width:12px;
    filter: invert(35%) sepia(85%) saturate(855%) hue-rotate(173deg) brightness(91%) contrast(90%);
}

.outcome-edit{
    margin-top:5px;
    display:inline-block;
    vertical-align: top;
    max-width:1000px;
}

.outcome-edit .outcome{
    
}

.right-panel-inner .parent-outcome-node{
    position:relative;
}

.right-panel-inner .parent-outcome-node > *:first-child{
    width:16px;
    left:8px;
    top:6px;
    position:absolute;
}

.right-panel-inner .parent-outcome-node > .outcome{
    margin-left:4px;
    padding-left:24px;
}

.restore-bar-item{
    border:2px solid #04ba74;
    border-radius:5px;
    padding:5px;
}


.outcome-workflow{
    margin-bottom:2px;
}

.outcome-bar-outcome-block .outcome{
    margin-left:0px;
    min-width:0px;
}

.outcome-bar-outcome-block .outcome-outcome{
    margin-bottom:2px;
}

.outcome-bar-outcome-block .children-block{
    margin-left:5px;
    border:0px;
}

.outcome-bar-outcome-block > div > .outcome, .outcome-bar-outcome-block .parent-outcome-node > .outcome{
    border: 1px solid #04ba74;
    border-radius: 5px;
    margin-bottom: 2px;
}

.outcome-bar-outcome-block .outcome-drop{
    margin-left:0px;
}
.outcome-bar-outcome-block .outcome-title, .outcome-node-container .outcome-title{
    font-size:10px;
}

.outcome-bar-outcome-block .outcome-title{
    cursor:pointer;
}

.outcome-ghost{
    width:160px;
    min-height:20px;
    border:1px dashed black;
    position:absolute;
}

.side-actions{
    position:absolute;
    top:0px;
    right:-22px;
}
/*
.competency-matrix .nodewrapper .side-actions{
    top: -202px;
    left: 0px;
    right: auto;
}*/

.outcome-table .nodewrapper .side-actions{
    top: -160px;
    right: -70px;
}

.side-actions .comment-indicator{
    position: unset;
    background: unset;
}

.outcome-node-container{
    display:none;
    position:absolute;
    top:0px;
    left:0px;
    background:white;
    border:2px solid;
    border-radius:10px;
    z-index:1;
    background:white;
    width:200px;
}

.outcome-node-indicator-number{
    display:inline-block;
    min-width:16px;
    height:16px;
    background:white;
    border: 2px solid;
    border-radius:10px;
    text-align:center;
}

.outcome-node-indicator:hover .outcome-node-container{
    display:inline-block;
}

.outcome-node-container .outcome{
    min-width:initial;
    max-width:initial;
    margin:0px;
    border:0px;
}

.outcome-node-container .children-block{
    margin-left:5px;
    border:0px;
}

.outcome-node-container .outcome-drop{
    margin-left:0px;
}

.outcome-node-container .outcome-node{
    position:relative;
}

.outcome-node img{
    width:16px;
}

.outcome-node >.outcome>.outcome-title{
    margin-left:0px;
}

.outcome-node >.outcome{
    margin-left:0px;
}

.outcome-node{
    display:flex;
    align-items:center;
}

.outcome-node .outcome-degree{
    width:16px;
    text-align:center;
}

.outcome-degree{
    font-family:serif;
}

.outcome-node-container .outcome-title{
    margin-left:16px;
}

.outcome-node-container .action-button{
    width:12px;
    height:12px;
    margin-left:4px;
}

.outcome-node-container .mouseover-actions{
    right:auto;
    left:2px;
    top:2px;
}

.outcome-node-container .outcome-outcome{
    position:relative;
    left:4px;
}

.outcome-hover, .outcome-toggle{
    outline:2px solid #ffff80;
}

.outcome-toggle-checkbox{
    position:absolute;
    right:-2px;
    top:-2px;
    display:none;
}

.outcome-hover>.outcome-toggle-checkbox{
    display:block;
}

.outcome-bar-outcome-block .outcome-outcome{
    background:white;
}

.outcome-table{
    margin-right:80px;
}

.outcome-table .outcome{
    max-width:none;
    padding:0;
    border:0px;
    font-size: 12px;
    margin-left:0px;
}

.outcome-table .children-block{
    margin-left:0px;
    border-left:0px;
}

.outcome-table .outcome-title{
    padding-bottom:0px;
    padding-top:1px;
}

.outcome-table .outcome-drop{
    margin-top:-2px;
    margin-left:-2px;
}

.outcome-table .node-row .outcome-head{
    background:white;
    position:sticky;
    left:0px;
    height:100%;
    z-index:1;
}

.outcome-table .table-cell, .competency-matrix .table-cell{
    width:30px;
    min-height:24px;
    border-left:1px solid black;
    vertical-align:top;
    text-align:center;
    position:relative;
    box-shadow:0px 1px 0 0 #dddddd;
}

.outcome-table .table-cell{
    display: inline-block;
    height:100%;
}


.outcome-table .blank-cell{
    box-shadow:none;
}

.outcome-table .horizontal-table-node{
    position:absolute;
    font-weight:600;
    font-size:14px;
    border-bottom:1px solid black;
    padding:4px;
    padding-top:5px;
    top:4px;
    width:32px;
    box-sizing:border-box;
    overflow:hidden;
    z-index:1;
}

.outcome-table .horizontal-table-header{
    display:inline-block;
    position:relative;
}

.outcome-table .total-cell, .outcome-table .total-header, .competency-matrix .total-cell, .competency-matrix .total-header{
    background:#EAEAEA;
}

.outcome-table .table-cell.disabled, .outcome-table .table-cell.disabled .child-outcome{
    background:#BABABA;
}
.outcome-table .table-cell.not-first-child-outcome{
    border-left:2px solid transparent;
}
.outcome-table .table-cell.not-first-child-outcome .child-outcome{
    border-top:2px solid transparent;
}

.outcome-table .grand-total-cell{
    border-right:1px solid black;
}

.outcome-table.node-rows .outcome-head.user-head{
    width: 200px;
    border-right: none;
}

.user-table .table-cell input{
    display: block;
}

.user-table .table-cell .workflow-title{
    font-size: 12px;
}

.user-table{
    white-space: nowrap;
}

/*
.competency-matrix .outcome{
    font-size:14px;
    transform-origin:top left;
    transform: rotate(-90deg);
    position:absolute;
    margin:0px;
    border-bottom:2px solid black;
    text-align:left;
    height:30px;
    box-sizing:border-box;
    left:2px;
    min-width:revert;
    width:180px;
}

.competency-matrix .outcome .title-text{
    overflow:hidden;
    white-space:normal;
    width:100%;
    height:100%;
}

.competency-matrix .outcome-drop{
    margin:0px;
    left:-20px;
    top:8px;
    position:absolute;
}

.competency-matrix .outcome-block{
    height:100%;
    display:inline-block;
}

.competency-matrix .outcome-block.dropped > .outcome-block-children{
    display:inline-block;
}

.competency-matrix .outcome-block-children{
    height:100%;
    display:none;
}

.competency-matrix .outcome-row.node-row{
    padding-top:200px;
}

.competency-matrix .node{
    width:100%;
    height:26px;
    display:inline-block;
    vertical-align:top;
}

.competency-matrix .week .node-row:first-child .outcome-header{
    background:#E0E0E0;
}

.competency-matrix .week{
    background:none;
    min-height:revert;
    padding:0;
    margin:0;
    border:0px;
}


.competency-matrix .outcome-head{
    display:inline-block;
    width:160px;
}*/


.competency-matrix .outcome-row.node-row{
    position:sticky;
    left:0px;
    z-index:2;
    background:white;
}

.competency-matrix .outcome-row.node-row .table-cell{
    width: 202px;
    border-left: 0px;
}

.competency-matrix .table-body{
    display: inline-block;
    vertical-align: top;
}

.competency-matrix .node-top-row{
    padding: 2px;
    border-radius: 0 0 5px 5px;
}

.competency-matrix .outcome-row{
    display: inline-block;
    position: relative;
    vertical-align: top;
}

.competency-matrix .week .node-row:first-child{
    background:#E0E0E0;
}

.competency-matrix .table-cell{
    height:30px;
}

.competency-matrix .outcome-wrapper{
    width: 30px;
    position: sticky;
    top: 180px;
    z-index: 3;
}

.competency-matrix .outcome-head{
    font-size:14px;
    transform-origin:top left;
    transform: rotate(-90deg);
    position:absolute;
    margin:0px;
    border-top:1px solid black;
    text-align:left;
    height:30px;
    box-sizing:border-box;
    left:0px;
    min-width:revert;
    width:180px;    
    background: white;
}

.competency-matrix .matrix-time-block{
    display: inline-block;
}

.competency-matrix .matrix-time-block .outcome-head{
    left: -1px;
}

.matrix-time-block > .matrix-time-row:first-child {
    position: sticky;
    top: 180px;
    z-index: 3;
}

.competency-matrix .matrix-time-block .table-cell{
    display: inline-block;
}

.competency-matrix .node-row .outcome-head{
    border: 0px;
    height: 203px;
    left: 0px;
}

.competency-matrix .outcome-title{
    padding-top: 0px;
    max-height: 20px;
    overflow-y: hidden;
}

.competency-matrix .outcome-drop{
    position: relative;
    top: -5px;
}

.competency-matrix .outcome-row+.outcome-row:not(.depth-0) .table-cell{
    border-left: 0px;
}

.competency-matrix .outcome-row+.outcome-row:not(.depth-0) .outcome-head{
    border-top: 0px;
}

.competency-matrix{
    padding: 40px;
    padding-top: 220px;

}

.workflow-grid{
    display:flex;
}

.workflow-grid .week{
    margin-right: 20px;
}

.workflow-grid .node-top-row{
    border-radius:0 0 5px 5px;
}

.grid-ponderation{
    font-size:14px;
    font-weight:600;
    margin:5px;
}

.outcome-row:not(.node-row):hover, .outcome-row:not(.node-row):hover .total-cell{
    background:#E0E0E0;
}

.outcome-row:not(.node-row):hover .outcome-head{
    background: #E0E0E0;
}

.table-cell .outcome-degree{
    display:inline-block;
    font-family:serif;
    font-weight:600;
    white-space:nowrap;
    margin-top:6px;
    opacity:0.7;
}
.outcome-introduced{
    color:#167016;
}
.outcome-introduced.self-completed{
    color:white;
    background:#167016;
    opacity:1;
    min-width:10px;
}
.outcome-developed{
    color:#2ca02c;
}
.outcome-developed.self-completed{
    color:white;
    background:#2ca02c;
    opacity:1;
    min-width:10px;
}
.outcome-advanced{
    color:#11ca11;
}
.outcome-advanced.self-completed{
    color:white;
    background:#11ca11;
    opacity:1;
    min-width:10px;
}

.outcome-table .table-group{
    display:inline-block;
    height:100%;
}

.outcome-cells{
    display:inline-block;
    vertical-align: top;
}

.outcome-table.node-rows .outcome-head{
    height: 100%;
}

.outcome-table .outcome-wrapper{
    display:inline-block;
    width:280px;
    position:sticky;
    left:0px;
    background:white;
    z-index:1;
    box-sizing:border-box;
    border-right:2px solid #E9EBF2;
}

.outcome-table .outcome-head.empty{
    border-right-color:white;
    position:relative;
    width: 280px;
}

.outcome-table.node-rows .outcome .outcome .outcome-head{
    border-left:2px solid #04ba74;
}

.outcome-row{
    display:flex;
}


.outcome-table .outcome-row.node-row{
    padding-top:140px;
    position:sticky;
    top:0px;
    z-index:2;
    background:white;
}


.outcome-table .outcome-row.outcome-category{
    border-bottom:2px solid #E9EBF2;
    border-top:2px solid #E9EBF2;
}

.outcome-row.outcome-category h4{
    margin-left:5px;
    margin-top:0px;
    margin-bottom:0px;
}

.outcome-table .table-cell.nodewrapper{
    position:relative;
}

.table-cell > img{
    padding:5px;
    width:16px;
    opacity:0.7;
}

.table-cell > img.self-completed{
    opacity:1;
}

.table-cell input, .table-cell button, .table-cell select{
    position:absolute;
    top:3px;
    right:4px;
    display:none;
}

.table-cell select:focus{
    display: inline-block;
}

.table-cell select{
    width: 30px;
    right: 0px;
}

.table-cell button{
    background:white;
    box-shadow:none;
    border:1px solid black;
    border-radius:3px;
}

.table-cell:hover input, .table-cell:hover button, .table-cell:hover select{
    display:inline-block;
}

.outcome-table.node-rows .node, .outcome-table.node-rows .child-outcome{
    width:160px;
    position:absolute;
    left:-2px;
    height:26px;
    transform-origin:top left;
    transform:rotate(-60deg);
    
}

.outcome-table .child-outcome{
    border-top:1px solid black;
    text-align:left;
    padding-left:10px;
    white-space:normal;
    overflow:hidden;
    font-size:11px;
    font-weight:600;
}


.outcome-table .node-title{
    width:100%;
    min-height:0px;
    max-height:18px;
}

.outcome-table .node-top-row{
    padding:1px;
    border-radius:0px 0px 5px 5px;
    height: calc(100% - 5px);
}

.outcome-table .table-cell .total-header, .outcome-table .table-cell .node-category-header{
    position:absolute;
    width:160px;
    height:26px;
    transform-origin:top left;
    transform:rotate(-60deg);
    border-bottom:0px;
    font-weight:600;
    text-align:left;
    font-size:10px;
    white-space:normal;
    background: inherit;
    border-top: 1px solid black;
    left: -1px;
}

.outcome-table .total-header::before, .outcome-table .node-category-header::before{
    content:"";
    width:16px;
    height:5px;
    display:inline-block;
}

.outcome-table .total-header::after{
    content:"";
    position:absolute;
    margin-left:14px;
    border-bottom:1px solid black;
    bottom:-2px;
    width:calc(100% - 14px);
    left:0px;
}

.outcome-table .table-cell .node-category-header{
    font-size:12px;
    overflow-y: auto;
    overflow-x: hidden;
}

.outcome-table .table-group:first-child .blank-cell{
    border-left:0px;
}

.viewbar .outcomeviewtext{
    display:block;
    white-space: nowrap;
}

.switch{
    position: relative;
    display:inline-block;
    width:60px;
    height:16px;
}

.slider{
    position:absolute;
    cursor:pointer;
    top:0;
    left:0;
    right:0;
    bottom:0;
    background-color:grey;
    transition:0.4s;
    border-radius:34px;
}

.slider::before{
    border-radius:50%;
    position:absolute;
    content:"";
    height:12px;
    width:12px;
    left:4px;
    bottom:2px;
    background-color:white;
    transition:.4s;
}


input:checked + .slider{
    background-color:#04ba74;
}

input:checked +.slider::before{
    transform:translateX(40px);
}

.mouseover-actions{
    visibility:hidden;
    position:absolute;
    top:-1px;
    right:-1px;
    border-radius:5px;
    border:0px solid black;
    padding:2px;
    line-height:0px;
    background:white;
}

/*This is used to get around the issue that we can't make the week itself relatively positioned (messes up jquery sortable*/
.mouseover-container-bypass{
    position:relative;
    padding:0;
    margin:0;
    top:0px;
    width:100%;
    height:0px;
    overflow:visible;
}

.action-button{
    width:20px;
    height:20px;
    display:inline-block;
    cursor:pointer;
}

.action-button img{
    width:100%;
    height:100%;
}


div:hover > .mouseover-actions,div:hover > .mouseover-container-bypass > .mouseover-actions{
    visibility:visible;
}


.dragging .mouseover-actions{
    visibility:hidden !important;
}

.comment-box{
    text-align:left;
    position:absolute;
    width:300px;
    max-height:400px;
    border:1px solid #04ba74;
    background:white;
    z-index:7;
    overflow: overlay;
    padding: 5px;
    font-size: 12px;
    box-sizing: border-box;
    top:0px;
    right:-305px;
    border-radius:5px;
    box-shadow: 0px 1px 2px 1px rgba(0,0,0,0.3);
}

.comment-top-row{
    display: flex;
    flex-direction: row-reverse;
    gap: 16px;
}

.comment-top-row img{
    width: 20px;
}

.comment-block{
    width: 100%;
    box-sizing: border-box;
}

.comment .mouseover-actions{
    top: 1px;
    right: 1px;
}

.comment .action-button{
    width: 12px;
    height: 12px;
}

.comment-box .comment-input-line{
    width:100%;
    box-sizing: border-box;
    margin:0px;
    margin-top:4px;
}

.add-comment-button{
    width: 20px;
    margin: 10px;
}

.add-comment-button.hidden{
    display: none;
}

.comment-input-line{
    display: flex;
    align-items: center;
}

.comment-box button.small{
    padding:4px;
    font-size:10px;
}

.comment-box .comment-input{
    min-height: 60px;
    max-height:100px;
    white-space:normal;
    background: #EEEEEE;
    flex-grow: 99;
    border: none;
    border-radius: 5px;
    resize: none;
}

.comment-text{
    white-space:pre-line;
}

.comment{
    position:relative;
    margin-top:5px;
    padding:2px;
    padding-bottom:5px;
    border:1px solid white;
    box-sizing: border-box;
    width: 100%;
    overflow-x: hidden;
    color: #222222;
    -webkit-user-select: text;
            user-select: text;
}

.comment:hover{
    border:1px solid #E9EBF2;
    
}

.comment-by{
    display: flex;
    justify-content: space-between;
}
.comment-on{
    font-size:10px;
    color: grey;
}
.comment-user{
    font-size:14px;
    font-weight: 600;

}

.comment-indicator{
    position:absolute;
    right:0px;
    top:0px;
    border-radius:5px;
    background:white;
    height:20px;
}

.week > .comment-indicator{
    margin-right:10px;
    margin-top:10px;
}

.comment-indicator img{
    width:20px;
    filter: brightness(0) saturate(100%) invert(38%) sepia(98%) saturate(461%) hue-rotate(164deg) brightness(87%) contrast(100%);
}

.outcome-node-container .comment-indicator img{
    width: 12px;
}

.nomenclature-row{
    position:relative;
    width:-moz-fit-content;
    width:fit-content;
    padding:8px;
    padding-left:0px;
    display: flex;
    gap: 20px;
    align-items: center;
}

.nomenclature-row div:first-child{
    width: 150px;
}


.nomenclature-row input, .nomenclature-row select {
    padding: 10px;
    border-radius: 3px;
    border: 1px solid black;
}

.workflow-canvas{
    position:absolute;
    left:0px;
    top:0px;
    pointer-events:none;
}

.nodelinkwrapper{
    width:100px;
    height:100px;
    overflow:hidden;
    pointer-events: none;
    display:flex;
    justify-content:center;
    align-items:center;
}

.nodelinktext {
    text-anchor: middle;
    dominant-baseline: middle;
    max-width: 100px;
    max-height: 100px;
    white-space: normal;
    background: white;
    padding: 2px;
    border: 1px solid black;
    font-size: 10px;
    text-align: center;
    width:-moz-fit-content;
    width:fit-content;
    pointer-events:all;
}


.workflow-canvas circle, .workflow-canvas path.nodelink{
    pointer-events:auto;
}

.workflow-canvas.creating-node-link circle[data-port-type='target']{
    visibility:visible;
}

.workflow-canvas circle{
    visibility:hidden;
}

circle.mouseover{
    visibility:visible;
}

.workflow-canvas.dragging-weekworkflow{
    opacity:0;
}
/*
.node input{
    width:100px;
}*/

.side-bar{
    z-index:4;
    height: 100%;
    max-width:260px;
    position: relative;
}


.right-panel-container{
    float:right;
    box-shadow: -1px 0px 1px -1px;
    background:white;
    text-align:left;
    font-family:sans-serif;
    height:100%;
    width:260px;
    position:relative;
}

.side-bar hr{
    margin: 10px;
    margin-left: 10%;
    margin-right: 10%;
}

.side-bar .ui-tabs-tab.hidden{
    display: none;
}

.side-bar.collapsed .window-close-button{
    display:none;
}

.side-bar .ui-tabs-nav{
    margin:5px -2px 5px 5px; 
    padding:0px;
    left:-40px;
    top: 36px;
    position:absolute;
}

.side-bar .ui-tabs-tab{
    text-align:center;
    display:block;
    background:white;
    border-radius:3px;
    margin: 1px;
    margin-bottom: 2px;
    padding: 6px;
    box-sizing: border-box;
    box-shadow: 0px 4px 4px 2px #e6e6e6;
    color: #04ba74;
}

.side-bar .ui-tabs-tab.ui-state-disabled{
    background-color:#E9EBF2;
    cursor:default;
    color: #B5B5B5;
}


.side-bar .ui-tabs-tab a span{
    font-size: 20px;
    margin-top: 2px;
    margin-left: 1px;
}

.side-bar .ui-tabs-tab a{
    margin-right:4px;
    display:block;
    text-decoration:none;
    box-sizing:border-box;
    height:24px;
    color: inherit;
}


.side-bar .ui-tabs-tab.ui-tabs-active{
    color: white;
    background: #04ba74;
}



.side-bar select, .side-bar input[type=text], .side-bar textarea, .side-bar input[type=number]{
    width:100%;
    box-sizing:border-box;
    padding:5px;
    border:1px solid lightgrey;
    margin-top:2px;
    margin-bottom:2px;
}

.side-bar input[type=number]{
    -moz-appearance:textfield;
}

.side-bar input::-webkit-outer-spin-button,
.side-bar input::-webkit-inner-spin-button {
    -webkit-appearance: none;
    margin: 0;
}

.side-bar button{
    margin-top:2px;
    margin-bottom:2px;
    box-sizing:100%;
    width:100%
}

.side-bar input[type=text]{
    padding-top:6px;
    padding-bottom:6px;
}


.side-bar .quill-div{
    min-height:140px;
    position:unset;
}

.side-bar #title-editor{
    min-height:60px;
    max-height: 100px;
}

.side-bar .character-length{
    font-size:10px;
    color:grey;
    float: right;
}

.side-bar .character-length.overflow{
    color:red;
}

.side-bar input.half-width, .side-bar select.half-width{
    width:50%;
}

.side-bar .delete-self-button{
    margin:5px;
    text-align:center;
}

.half-width{
    width:50%;
    display:inline-block;
    box-sizing:border-box;
}

.right-panel-container textarea{
    font-family:sans-serif;
    resize:none;
}

.right-panel-inner{
    overflow-y: overlay;
    display:inline-block;
    padding:20px;
    box-sizing:border-box;
    width:100%;
    height:100%;
}

.slidecontainer{
    width:100%;
}

.range-slider{
  -webkit-appearance: none;
          appearance: none;
  width: 100%; /* Full-width */
  height: 25px; /* Specified height */
  background: #d3d3d3; /* Grey background */
  outline: none; /* Remove outline */
  opacity: 0.7; /* Set transparency (for mouse-over effects on hover) */
  transition: opacity .2s;
  border-radius:20px;
}

.range-slider:hover {
  opacity: 1; /* Fully shown on mouse-over */
}


.node-bar-column-workflow{
    width:100%;
    display:block;
    margin:2px;
}

.node-bar-column-workflow .ui-sortable-placeholder{
    display:none;
}

.node-bar-column{
    font-size:14px;
    width:100%;
    cursor:move;
    padding:8px;
    border-radius: 5px;
    color: white;
    box-sizing: border-box;
}

.node-bar-column.new-column{
    color: black;
    border: 2px black;
}

.new-column.node-bar-column{
    border-style:dashed;
}

.new-node-drop-over{
    border-bottom:2px solid #04ba74;
}

.outcome-drop-over{
    border:2px solid #04ba74;
}

.new-strategy-drop-over{
    border-bottom:2px solid #04ba74;
}

.valid-drop{
    outline:2px solid #04ba74;
}

.node-bar-week{
    padding: 2px;
    font-weight: 600;
    margin-bottom: 2px;
}

.strategy-bar-strategy{
    width:100%;
    display:block;
    margin:2px;
    font-size:14px;
    padding:8px;
    cursor:move;
    box-sizing:border-box;
    white-space:nowrap;
    background: #660385;
    border-radius: 5px;
    color: white;
}

.strategy-bar-strategy img{
    width:24px;
    display:inline-block;
    vertical-align:middle;
}
.strategy-bar-strategy div{
    display:inline-block;
    vertical-align:middle;
    margin-left:8px;
    white-space:normal;
}

.week-ghost{
    width:300px;
    min-height:50px;
    border:1px dashed black;
    position:absolute;
}

.workflow-wrapper .selected{
    border-color:#04ba74;
    border-style:solid;
}

.workflow-wrapper .nodelink.selected{
    stroke:#04ba74;
    opacity:1;
    stroke-width:5px;
}

.workflow-wrapper .node.selected{
    border-width:2px;
    margin:-1px;
}

.workflow-for-menu.selected{
    border-color:#04ba74;
}

.alignment-block{

}

.alignment-block > .outcome > .mouseover-actions{
    display:none !important;
}

.alignment-block .node{
    width:100%;
    white-space:nowrap;
}

.alignment-block .week .node-block{
    display: block;
}

.alignment-block .node-title{
    width:200px;
    vertical-align: middle;
    display:inline-block;
}

.alignment-block .outcomenode-block{
    display:inline-block;
    vertical-align: middle;
    max-width:600px;
}

.alignment-block .outcomenode-block .mouseover-actions{
    display:none !important;
}

.alignment-block .node-drop-row{
    height:auto;
    padding-left:20px;
    border-top:2px solid #E9EBF2;
    box-sizing:border-box;
}

.alignment-block .parent-outcome-box,.alignment-block .child-outcome-box{
    display:inline-block;
    vertical-align:top;
    white-space:normal;
}

.alignment-block .parent-outcome-box{
    width:30%;
}
.alignment-block .child-outcome-box{
    width:70%;
}

.alignment-block .outcome-alignment{
    white-space:nowrap;
    max-width:800px;
    box-sizing:border-box;
    padding:8px;
    margin:2px;
    border:2px solid white;
}

.alignment-block .outcome-alignment:hover{
    border-color:gray;
}

.alignment-block img{
    width:16px;
}

.alignment-row{
    margin-bottom:4px;
}

.alignment-row > *{
    vertical-align:top;
    margin-right:4px;
}

.alignment-row > *:not(img):not(.outcome-degree){
    min-width:0px;
    width:calc(100% - 50px);
}

.alignment-column .outcome{
    min-width:0px;
    width:calc(100% - 50px);
}

.alignment-column{
    min-width:400px;
}

.alignment-show-all{
    color:#04ba74;
    cursor:pointer;
}

.alignment-block .outcome-block{
    background-color:white;
}

.alignment-block .child-outcome{
    padding-bottom:5px;
    border-top:2px solid #E9EBF2;
}

.alignment-block .child-outcome.child-outcome-header{
    font-weight: 600;
    padding-left: 5px;
}

.alignment-block .child-outcome .half-width{
    vertical-align: top;
}

.alignment-block .child-outcome{
    font-size: 12px;
}

.alignment-block .alignment-added-outcomes{
    font-size: 12px;
}

.alignment-block .node-outcomes-header{
    font-weight: 600;
}

#popup-container{
    position:absolute;
    width:100%;
    height:100%;
    pointer-events:none;
    z-index:10;
    top: 0;
    left: 0;
}


.multi-select{
    display:inline-block;
    width:250px;
}

.multi-select select{
    height:200px;
}

.multi-select >*{
    display:block;
    width:100%;
}

.message-panel{
    width:50%;
    text-align:left;
    box-sizing: border-box;
    display:inline-block;
    background:white;
    height:100%;
    padding:20px;
    overflow: overlay;
    vertical-align:top;
}

.action-bar{
    display:flex;
    gap: 10px;
    right:15px;
    bottom:15px;
    position:absolute;
}

.workflow-legend{
    cursor:move;
    position:fixed;
    background:white;
    z-index:5;
    padding:20px;
    border:2px solid #04ba74;
    left:calc(100% - 460px);
    box-shadow: 0px 2px 2px 0px rgba(0,0,0,0.3);
}

.workflow-legend .legend-section{
    
}

.workflow-legend .legend-line{
    width:100%;
    padding:2px;
}

.workflow-legend .legend-line img{
    display:inline-block;
    vertical-align: middle;
    width:24px
}

.workflow-legend .legend-line div{
    display:inline-block;
    vertical-align: middle;
    margin-left:8px;
    font-weight:600;
    font-size:12px;
}

/*ComparisonView stuff*/

.comparison-view{
    display:flex;
    gap:20px;
    padding:50px;
}

.comparison-view .workflow-description, .comparison-view .workflow-publication{
    display: none;
}

.comparison-view .workflow-title{
    font-size: 12px;
}

.comparison-view .workflow-array{
    display:flex;
    gap:20px;
}

.comparison-view .node-week{
    padding-top:5px;
    max-width:204px;
    white-space:normal;
}

.comparison-view .node-top-row{
    border-radius:0 0 5px 5px;
}

.comparison-view .week{
    min-height:60px;
    box-sizing:content-box;
}

.comparison-view .node-block{
    min-height:30px;
}

.comparison-view .workflow-container{
    padding:0;
    box-shadow:none;
    margin:0;
}

.comparison-view .workflow-header{
    margin:0px;
    position:sticky;
    z-index:1;
    top:0px;
    border:1px solid black;
    display:flex;
}

.comparison-view .workflow-details{
    padding:5px;
    box-sizing: border-box;
    width: 100%;
}

.comparison-view .workflow-wrapper{
    margin:0px;
    width:260px;
    position: relative;
    min-width: auto;
    padding: 0;
}

.comparison-view .workflow-for-menu{
    margin:0px;
    width:100%;
    padding: 5px;
}

.comparison-view .outcome{
    margin-left: 0;
    min-width: unset;
    max-width: 210px;
    font-size: 12px;
}

.workflow-wrapper .window-close-button {
    right: -8px;
    top: -8px;
    background: white;
    height: 16px;
    width: 16px;
    border-radius: 8px;
    z-index: 2;
}


/*
.workflow-legend *:is(h4, h5), .right-panel-container *:is(h3, h4, h5){
    color:#04ba74;
}
*/
.selectable{
    -webkit-user-select: unset;
            user-select: unset;
}

.load-screen{
    z-index:99;
    position:absolute;
    left:0;
    top:0;
    width:100%;
    height:100%;
    background:#80808060;
}
.load-screen::after{
    position:absolute;
    left:50%;
    top:50%;
    width:50px;
    height:50px;
    margin:-25px 0 0 -25px;
    content:"";
    border-radius:50%;
    border:16px solid #80808010;
    border-top:16px solid #04ba74;
    border-bottom:16px solid #04ba74;
    animation: spin 2s linear infinite;
    -webkit-animation: spin 2s linear infinite;
}

@keyframes spin {
  0% { transform: rotate(0deg); }
  100% { transform: rotate(360deg); }
}

*.waiting, *.waiting *{
    cursor:wait !important;
}



:root {
  --mdc-theme-primary: #04ba74;
  --mdc-theme-secondary: #46c443;
}

body, html{
    overflow:hidden;
    margin:0px;
    height:100%;
    font-family:'Open Sans',sans-serif;
    font-size: 14px;
}

hr{
    margin:4px;
    margin-left:10%;
    margin-right:10%;
    border-top: 1px solid #E9EBF2;
    border-left: 0px;
}

h1{
    color:#04ba74;
    
}

h2{
    font-size:28px;
    font-weight: 500;
}

h3{
    /*color:#04ba74;*/
    color: #444444;
}

h4{
    margin-top:10px;
    margin-bottom:5px;
    color: #444444;
    font-weight: 600;
    /*color:#04ba74;*/
}
h5{
    margin-top:8px;
    margin-bottom:8px;
    color:#04ba74;
}

h4.drag-and-drop::after, h3.drag-and-drop::after{
    content:"\A Drag and drop to add";
    font-size:10px;
    color:grey;
    white-space:pre;
}

body.printing{
    height: unset;
}

input[type="checkbox"], input[type="radio"]{
    filter: hue-rotate(300deg) brightness(117%)
}

textarea{
    font-family: 'Open Sans';
}

button.disabled, button:disabled{
    pointer-events: none;
    cursor: default;
}

.ui-state-disabled, .disabled, *:disabled .ui-state-disabled *, .disabled *, *:disabled *{
    cursor: default !important;
}

.hover-shade:not(.ui-state-disabled):not(.disabled):not([disabled]){
    cursor:pointer;
}
.hover-shade:not(.ui-state-disabled):not(.disabled):not([disabled]):hover{
    box-shadow: inset 0 0 0 9999px rgba(0,0,0,0.04);
}

::-webkit-scrollbar:hover {
  width: 8px;
  height: 8px;
}

::-webkit-scrollbar {
  width: 4px;
  height: 4px;
}

::-webkit-scrollbar-track {
  background: transparent;
}

::-webkit-scrollbar-thumb {
  background: #888888;
  border-radius: 2px;
}

::-webkit-scrollbar-thumb:hover {
  background: #6E6E6E;
}

::-webkit-scrollbar-button{
    height: 0px;
}

.left-panel a, .workflow-title-bar a, .home-item a{
    color:#444444;
}

a.hover-shade{
    color: unset;
    text-decoration: none;
}

a.unset{
    color: unset;
    text-decoration: none;
}
/*
a.hover-shade:hover{
    text-decoration:underline;
}*/

.material-symbols-rounded.filled, .material-symbols-outlined.filled{
    font-variation-settings: 'FILL' 1;
}


body{
    background:#EEEEEE;
}

button{
    cursor:pointer;
}

.primary-button{
    background: #04BA74;
    color: white;
    padding: 8px;
    box-sizing: border-box;
    border: 0;
}

.secondary-button{
    color: #444444;
    background: #E9EBF2;
    padding: 8px;
    box-sizing: border-box;
    border: 0;
}

.primary-button.disabled, .primary-button:disabled, .secondary-button.disabled, .secondary-button:disabled{
    background: #04BA74;
    color: grey;
    background: #E9EBF2;
}

.flex-middle{
    display: flex;
    gap: 10px;
    align-items: center;
}

.relative{
    position: relative;
}

.inline{
    display: inline;
}

hr.big-space{
    margin-top: 30px;
    margin-bottom: 30px;
    margin-left: 0px;
    margin-right: 0px;
}

h4.big-space, h3.big-space{
    margin-bottom: 20px;
}

[contentEditable=true]:empty:not(:focus):before {
  content: attr(data-text);
  color: grey;
}

.disabled{
    pointer-events: none;
    cursor:default;
    box-shadow:inset 0 0 0 99999px rgba(0,0,0,0.2);
}

button:hover{
    box-shadow:inset 0 0 0 99999px rgba(0,0,0,0.1);
}

.material-symbols-rounded.green, .material-symbols-outlined.green{
    color: #04ba74;
}

.material-symbols-rounded.red, .material-symbols-outlined.red{
    color: red;
}

.material-symbols-rounded.grey{
    color: #E9EBF2;
}

.material-symbols-rounded.small-inline{
    font-size: 14px;
    vertical-align: bottom;
}

.main-wrapper{
    display: flex;
    height: 100%;
    width: 100%;
}

.main-block{
    flex-grow: 1;
    overflow: hidden;
    display: flex;
    flex-direction: column;
}

.right-panel-wrapper{
    flex-grow: 1;
    overflow: hidden;
    display: flex;
    justify-content: space-between;
}

.topnav{
    width:100%;
    background: white;
    position: relative;
    box-sizing: border-box;
}

.topnav > div{
    padding-left: 40px;
}

/*
.topnav::before{
    content:'';
    position:absolute;
    bottom:0;
    left:0;
    right:0;
    height:2px;
    background:linear-gradient(to left,#46c443 0,#1976bc 100%) left bottom #fff no-repeat;
}
*/

.titlebar{
    height:36px;
    width:100%;
    color:#444444;
    position:relative;
    display:flex;
    justify-content: space-between;
    align-items: center;
    box-sizing: border-box;
}

.title{
    padding-left:20px;
    display:flex;
    flex-wrap: wrap;
    gap: 20px;
}

.title a .material-symbols-rounded{
    font-size: 20px;
}

.title a{
    display: flex;
}

.inline-title{
    display: inline;
}

#update-notifications{
    position: relative;
    background: #EEFFF8;
    margin: 0px 15px 15px 15px;
}

#update-notifications:empty{
    display: none;
}

#update-notifications .window-close-button{
    top: 3px;
}

#notification-inner{
    height: 32px;
    box-sizing: border-box;
    padding: 5px;
}

#notification-inner > *{
    vertical-align: middle;
}

#notification-inner > span{
    padding-right: 10px;
}

.menubar{
    display:flex;
    justify-content: space-between;
    width:100%;
    font-family:'Open Sans',sans-serif;
    align-items: center;
    background: #EEFFF8;
    box-sizing: border-box;
}

.menubar.hidden{
    display: none;
}

.workflow-title-bar{
    display:inline-block;
    max-width:800px;
    overflow:hidden;
    color:#444444;
    font-size:20px;
    font-weight:600;
    margin-left:20px;
}

.workflow-title-bar > div, .workflow-title-bar > a{
    padding:10px;
    display:inline-block;
}

.floatbar{
    flex-shrink:99;
    display: flex;
    align-items: center;
    gap: 10px;
    padding: 5px;
}

.floatbardiv{
    display:inline-block;
    vertical-align:middle;
    background:#1976bc;
    margin:5px;
    padding:5px;
    height:36px;
    color:white;
    box-sizing:border-box;
    white-space:nowrap;
    cursor:pointer;
}

.floatbardiv > *{
    display:inline-block;
}

.floatbar img{
    display:inline-block;
    vertical-align: middle;
    width:24px;
    margin:5px;
}

.floatbar > div{
    display:inline-block;
    vertical-align: middle;
    padding-left:6px;
    padding-right:6px;
    position: relative;
}

#visible-icons{
    display: flex;
    color: #04BA74;
    gap: 20px;
}

#overflow-options.hidden{
    display: none;
}

.users-box{
    position:relative;
    height:100%;
    margin-right: 20px;
    margin-bottom: 8px;
}

.users-box.connection-failed{
    color: red;
    font-weight: 600;
    display: flex;
    align-items: center;
}

.users-small .user-indicator{
    margin-top: 10px;
}

.user-indicator {
    color: white;
    display: inline-block;
    width: 20px;
    height: 20px;
    border-radius: 10px;
    text-align: center;
    vertical-align: middle;
}

.users-small{
    display:inline-block;
    display:flex;
    flex-wrap:wrap;
    max-width:76px;
    gap:20px 2px;
    height:100%;
    overflow:hidden;
}

.users-small-wrapper{
    height:100%;
    display:inline-block;
}

.users-more{
    display:inline-block;
    height:100%;
    color:black;
    padding-left:3px;
}

.users-hidden{
    display:none;
    position:absolute;
    padding:5px;
    background-color:white;
    border:1px solid grey;
    z-index: 10;
    right: 0px;
    top: 2px;
}

.users-more:hover+.users-hidden, .users-hidden:hover{
    display:inline-block;
}

#viewbar{
    color: #444444;
    margin-right: 10px;
    display: flex;
    align-items: center;
}

/*
.viewbar{
    display:inline-block;
    height:100%;
}

.viewbar > div{
    vertical-align: middle;
    padding:5px;
    padding-right:20px;
    display:inline-block;
    text-align:center;
}

.viewbar > div >img{
    width:30px;
    height:30px;
}*/

.topnavimage{
    box-sizing: border-box;
    display:inline-block;
    padding:5px;
    padding-bottom:0px;
    height:46px;
    padding-left:20px;
    padding-right:40px;
}

.topnavimage *{
    display:block;
    height:100%;
}


/* A wrapper for each button in the menu */
.topdropwrapper{
    display:inline-block;
    padding:0px;
    padding-top:3px;
    bottom:0px;
    vertical-align:top;
    min-width:48px;
}

/* A button at the top of the menu that will open the div below it */
.topdropbutton{
    background:inherit;
    color: rgb(25,118,188);
    border:inherit;
    font:inherit;
    height:48px;
    left:0;
    bottom:0;
    min-width:50px;
    padding-left:20px;
    padding-right:20px;
    font-weight:600;
}

.titlebar .topdropbutton{
    color:white;
}

.topdropbutton > a{
    display:block;
    color:white;
}

.topdropbutton > a:hover{
    text-decoration: none;
}

/* A tag at the top of the menu that does nothing*/
.toplink{
    left:0;
    bottom:0;
    padding-left:20px;
    padding-right:20px;
}


/* The div that is created below the button */
.topdropdiv{
    display:none;
    position:absolute;
    border: 1px solid grey;
    border-top: 1px solid black;
    color: black;
    background:white;
    min-width:100px;
    box-shadow: 0px 2px 2px 0px rgba(0,0,0,0.3);
}

.topdropdiv a{
    float:none;
    display:block;
    padding:4px;
    padding-left:12px;
    padding-right:12px;
    text-align:left;
    position:relative;
    cursor:pointer;
    white-space: nowrap;
}

.topdropdiv hr{
    margin-left:5px;
    margin-right:5px;
}

.topdroptitle{
    pointer-events: none;
}

.topdropindent{
    margin-left:12px;
}

.topdropdiv a div{
    display:inline-block;
}

.shortcut{
    color:gray;
    text-align:right;
    position:absolute;
    right:12px;
}

.topdropwrapper:hover .topdropdiv{
    display:block;
}

.topdropwrapper:hover .topdropbutton{
    box-shadow:inset 0 0 0 99999px rgba(0,0,0,0.1);
}

.topdropdiv a:hover{
    box-shadow:inset 0 0 0 99999px rgba(0,0,0,0.1);
    color: rgb(25,118,188);
}

.left-panel{
    background:white;
    min-width: 200px;
    width:200px;
    border-right:1px solid #E9EBF2;
    height:100%;
    box-sizing:border-box;
    color:#444444;
    display:flex;
    flex-direction:column;
    position: relative;
    z-index: 1;
    box-shadow: 0px 0px 10px #e6e6e6;
}

.left-panel.collapsed{
    min-width: 0px;
    width: 0px;
}

.left-panel.collapsed > *:not(.left-panel-toggle){
    display: none;
}

.left-panel.collapsed .left-panel-toggle{
    right: -30px;
}

.left-panel-toggle{
    width: 24px;
    height: 24px;
    background: #04ba74;
    border-radius: 50%;
    position: absolute;
    right: -10px;
    top: 6px;
    z-index: 10;
}

.left-panel:not(.collapsed) .left-panel-toggle{
    display: none;
}

.left-panel:not(.collapsed):hover .left-panel-toggle{
    display: block;
}

.left-panel-toggle .material-symbols-rounded{
    font-size: 20px;
    padding: 2px;
    color: white;
}

.collapsed #left-panel-collapse{
    display: none;
}

.left-panel:not(.collapsed) #left-panel-expand{
    display: none;
}

.left-panel-extra{
    overflow-y:overlay;
}

.title-image{
    padding:8px;
    margin-bottom:16px;
    margin-top: 16px;
    height:36px;
}

.panel-item{
    padding-left:14px;
    padding-right:14px;
    margin-left:6px;
    margin-right:6px;
    padding-top:8px;
    padding-bottom:8px;
    display:flex;
    align-items: center;
    font-size: 14px;
}

.panel-item.active{
    background: #EEFFF8;
}
.panel-favourite.active{
    background: #EEFFF8;
}

.panel-item > img, .panel-item .material-symbols-rounded{
    margin-right:10px;
}

.no-underline.hover-shade:hover{
    text-decoration: none;
}

/*.no-underline.hover-shade:hover > *:not(.material-symbols-rounded){
    text-decoration: underline;
}*/

.panel-item img{
    width:24px;
}

.panel-favourite{
    padding:3px;
    font-size:13px;
    display:block;
    margin-left:22px;
    margin-right:20px;
    overflow: hidden;
    -webkit-line-clamp: 1;
    display: -webkit-box;
    -webkit-box-orient: vertical;
}

.left-panel hr{
    margin-bottom:20px;
    margin-top:20px;
}

.home-menu-container{
    padding:40px;
    background:white;
    min-height: 100%;
    box-sizing: border-box;
    padding-left: 100px;
    padding-right: 100px;
    flex-direction: column;
    display: flex;
    gap: 50px;
    align-items: center;
}

.home-menu-container hr{
    margin-left:0;
    margin-right:0;
}

.home-menu-grid{
    display:flex;
    flex-wrap:wrap;
}


.home-item{
    border-radius:10px;
    border:1px solid #E9EBF2;
    width: -moz-fit-content;
    width: fit-content;
    max-width: 876px;
    min-width: 460px;
    padding: 30px;
    box-sizing: border-box;
}

.home-title-row{
    display: flex;
    justify-content: space-between;
    margin-bottom: 20px;
}

.home-item .home-item-title{
    font-size: 28px;
    color: #444444;
}

.home-item-icon-container{
    border-radius:10px;
    background:#1976bc;
    width:-moz-fit-content;
    width:fit-content;
    margin-left:126px;
}

.home-item-icon-container img{
    width:48px;
}

.home-tabs .ui-tabs-nav{
    padding:0px;
    margin:5px;
    overflow:hidden;
    box-sizing:border-box;
    z-index:1;
    min-width:250px;
    display:flex;
    gap: 5px;
    margin-bottom: 20px;
}

.home-tabs .ui-tabs-tab{
    font-size:16px;
    list-style:none;
    white-space:nowrap;
    background:white;
    padding: 8px;
    border-radius:20px;
    border:1px solid #E9EBF2;
}

.home-tabs .ui-tabs-active{
    background:#04ba74;
    border:1px solid #04ba74;
    color:white;
}

.home-tabs .ui-tabs-active a{
    color:white;
}

.home-tabs>div{
    width:100%;
    box-sizing: border-box;
    overflow-y:overlay;
}

.saltise-menu-container{
    height: 100%;
    width: 100%;
    background: white;
    padding: 50px;
    box-sizing: border-box;
    overflow: overlay;
}


.menu-create{
    padding:8px;
    background:#04ba74;
    color:white;
    display:block;
    border-radius:5px;
    width:-moz-fit-content;
    width:fit-content;
    margin-bottom:20px;
    margin-top:20px;
}


.menu-create>*{
    vertical-align:middle;
    display:inline-block;
}

.create-dropdown{
    display:none;
    z-index:1;
    background:white;
    position:absolute;
    padding-top:10px;
    padding-bottom: 10px;
    border-radius:10px;
    box-shadow: 0px 1px 3px 0px rgba(0,0,0,0.3);
    color: #444444;
    max-height: 400px;
    overflow-y: auto;
    overflow-x: hidden;
    width: max-content;
    max-width: 300px;
}

.create-dropdown .flex-middle {
    display: flex;
}

.dropdown-number-indicator{
    position: absolute;
    left: -4px;
    top: -4px;
    height: 16px;
    width: 16px;
    border-radius: 12px;
    background-color: #04BA74;
    color: white;
    font-size: 10px;
    line-height: 16px;
    text-align: center;
}

.dropdown-number-indicator[attr_number="0"] {
    display: none;
}

.floatbar .create-dropdown{
    margin-left:-6px;
    z-index: 5;
}

.create-dropdown.position-right{
    right: 0px;
}

#account-options, #create-options{
    position: relative;
}

/*#account-links, #create-links {
    right: 0px;
    width: max-content;
    max-width: 250px;
}*/

.create-dropdown > a, .create-dropdown > div{
    display:block;
    padding:8px;
    padding-left: 15px;
    padding-right: 15px;
    margin:0px;
    white-space: pre;
    color: #444444;
}

.create-dropdown > hr{
    margin-right: 0px;
    margin-left:  0px;
    margin-top: 10px;
    margin-bottom: 10px;
}

.create-dropdown.active, .create-dropdown.activate{
    display:block;
}

.menu-grid{
    display:flex;
    gap: 18px 14px;
    flex-wrap:wrap;
}

.message-wrap .menu-grid{
    margin-bottom: 10px;
}

.menu-grid > .workflow-for-menu{
    width:400px;
}

.workflow-for-menu{
    position:relative;
    background-color:white;
    padding:10px;
    border-radius:10px;
    border:1px solid #E9EBF2;
    max-width:600px;
    box-sizing: border-box;
}

.workflow-for-menu.simple-workflow{
    min-width: 200px;
    border-width: 0px;
}

.simple-workflow .workflow-title{
    font-size: 14px;
    font-weight: normal;
    width: 200px;
    min-width: 200px;
    max-width: 200px;
    overflow: hidden;
    -webkit-line-clamp: 1;
    display: -webkit-box;
    -webkit-box-orient: vertical;
}

.create-dropdown .workflow-top-row{
    gap: 10px;
    align-items: center;   
}

.create-dropdown .workflow-top-row .workflow-title{
    margin-bottom: 0;
}

.simple-workflow .workflow-type-indicator{
    min-width: 75px;
}

.simple-workflow .project-title{
    font-size: 14px;
    font-weight: normal;
    color: #878787;
    width: 200px;
    min-width: 200px;
    max-width: 200px;
    overflow: hidden;
    -webkit-line-clamp: 1;
    display: -webkit-box;
    -webkit-box-orient: vertical;
}

.workflow-buttons-row{
    display: flex;
    gap: 5px;
    flex-direction: row-reverse;
    justify-content: space-between;
}

.workflow-buttons-row > div{
    display: flex;
    gap: 5px;
}

.workflow-buttons-row .workflow-created{
    background: #E9EBF2;
    padding: 5px;
    padding-left: 12px;
    padding-right: 12px;
    border-radius: 4px;
    text-decoration: none;
    color: #444444;
}

.workflow-buttons-row .linked-workflow-warning{
    display: none;
}

.linked_workflow_menu .linked-workflow-warning{
    display: block;
}

.workflow-for-menu .workflow-toggle-favourite{
    color: #F7BA2A
}

.workflow-description{
    font-size:13px;
    color:#444444;
    margin-bottom:2px;
    white-space:pre-wrap;
    max-height: 140px;
    overflow-y: overlay;
}


.workflow-for-menu .workflow-description.collapsible-text{
    -webkit-line-clamp: 1;
    display: -webkit-box;
    -webkit-box-orient: vertical;
    overflow: hidden;
    margin-bottom: 12px;
}

.workflow-for-menu .workflow-description p, .menu-grid .workflow-description ul{
    margin: 0;
}

.workflow-for-menu .workflow-title{
    overflow: hidden;
    -webkit-line-clamp: 1;
    display: -webkit-box;
    -webkit-box-orient: vertical;
}

.workflow-publication{
    font-size:14px;
    color:gray;
}

.workflow-publication>*{
    display:inline-block;
    vertical-align: middle;
}

.workflow-publication>img{
    width:24px;
    margin-right:5px;
}

.workflow-created{
    font-size:12px;
    margin-bottom:6px;
    color:grey;
}

.warning{
    font-size: 12px;
    color: red;
}

.workflow-type-indicator{
    font-size:12px;
    color:white;
    border-radius:4px;
    padding:5px;
    padding-left:12px;
    padding-right:12px;
    height:-moz-fit-content;
    height:fit-content;
    white-space: nowrap;
}

.workflow-type-indicator.activity{
    /*background-color:#11b3d4;*/
    background-color: #0E5BB6;
}

.workflow-type-indicator.course{
    /*background-color:#ff5f3d;*/
    background-color:#C54A30;
}

.workflow-type-indicator.program{
    /*background-color:#04ba74;*/
    background-color:#327B77;
}

.workflow-type-indicator.project{
    /*background-color:#d6bb30;*/
    background-color:#B59C1B;
}

.workflow-type-indicator.liveproject{
    /*background-color:#8a38d1;*/
    background-color:#B59C1B;
}

.workflow-top-row{
    display:flex;
    align-items:flex-start;
    justify-content: space-between;
    gap: 10px;
}

.workflow-title{
    font-weight:600;
    font-size:16px;
    margin-bottom:6px;
    flex-grow:1;
    white-space:normal;
    text-decoration: none;
    color: #444444;
}

.workflow-buttons{
    text-align:right;
    white-space:nowrap;
    vertical-align:top;
}

.workflow-buttons > *{
    display:inline-block;
    padding:2px;
    cursor:pointer;
}

.workflow-buttons img{
    width:24px;
}


#project-description-input{
    min-width: 400px;
    min-height: 160px;
}

.project-import{
    margin-left:20px;
}

.project-menu{
    min-height:100%;
    width: -moz-fit-content;
    width: fit-content;
    background: white;
    padding: 50px;
    box-sizing: border-box;
    width: 100%;
}

.project-menu .menu-grid{
    overflow-y: auto;
}

.workflow-filter-top{
    display: flex;
    justify-content: space-between;
    width: 100%;
    margin-bottom: 40px;
}

.workflow-filter-sort{
    display: flex;
    gap: 20px;
}

#workflow-search{
    position: relative;
}

#workflow-search .create-dropdown{
    min-width: 500px;
    max-width: 600px;
}

.search-input + .material-symbols-rounded{
    position: absolute;
    font-size: 20px;
    left: 6px;
    top: 5px;
    color: grey;
}

.filter-option{
    position: relative;
}

.filter-option .material-symbols-rounded{
    position: absolute;
    left: -2px;
    font-size: 18px;
}

.filter-option.active{
    background: #EEFFF8;
}

.user-add .search-input{
    width: 100%;
}

.search-input{
    border-radius: 30px;
    border: 1px solid #E9EBF2;
    padding:  6px;
    padding-left: 30px;
    padding-right: 10px;
    box-sizing: border-box;
    font-size: 14px;
    width: 300px;
}

.search-filter-lock{
    color: white;
    border-radius: 3px;
    padding: 3px 10px 3px 10px;
    background: #027A4C;
    display: flex;
    vertical-align: middle;
    box-sizing: border-box;
}

.workflow-filter-sort > div{
    min-width: 100px;
    border-radius: 12px;
    height: 24px;
    padding: 2px;
    box-sizing: border-box;
    position: relative;
}

.workflow-filter-sort span{
    font-size: 20px;
}

.workflow-filter-sort .workflow-sort-indicator{
    display: flex;
    gap: 5px;
}
.workflow-filter-sort .workflow-sort-indicator:not(.item-0){
    background: #EEFFF8;
}

.project-header{
    border-radius:10px;
    background:white;
    width: 100%;
    color: #444444;
    padding-bottom: 10px;
    box-sizing: border-box;
}

.project-header-top-line{
    display: flex;
    gap: 20px;
    align-items: center;
}

.project-header h4{
    color: #444444;
}

.project-title{
    font-size: 28px;
}

.project-header-info{
    display: flex;
    gap: 20px;
}

.project-members{
    min-width: 250px;
    flex-grow: 1;
}

.project-other{
    flex-grow: 2;
}

.project-info-section{
    margin-top: 20px;
    margin-bottom: 20px;
    border-top: 1px solid #E9EBF2;
    max-width: 500px;
}

.title-text.collapsible-text{
    -webkit-line-clamp: 3;
    display: -webkit-box;
    -webkit-box-orient: vertical;
    overflow: hidden;
}

.title-text.collapsible-text.dropped{
    -webkit-line-clamp: unset;
}

.collapsed-text-show-more{
    text-decoration: underline !important;
    cursor: pointer;
}

.title-text{
    white-space: pre-wrap;
}

.explore-menu{
    width:100%;
    background-color:white;
    padding:50px;
    gap:30px;
    box-sizing:border-box;
}

.explore-menu .explore-menu .explore-preview{
    display:inline-block;
    vertical-align: top;
}

.explore-menu input[type="checkbox"]{
    visibility:hidden;
    position:absolute;
}

.explore-menu label.input{
    background:#f4f4f4;
    padding:5px 15px 5px 15px;
    border-radius:15px;
    border:1px solid transparent;
}

.explore-menu input:checked+label.input{
    background:#eefff8;
    border:1px solid #04ba74;
}

.explore-menu .explore-preview{
    overflow-x: overlay;
}

.explore-menu .explore-main{
    white-space: nowrap;
}

.explore-page-buttons{
    width: 100%;
    display: flex;
    justify-content: center;
    align-items: center;
    gap: 10px;
}

.explore-page-buttons button{
    width: 42px;
    height: 42px;
    border-radius: 100px;
    border: 1px solid black;
}

.explore-page-buttons button:disabled{
    border: 1px solid;
}

.explore-page-buttons .active-page-button{
    background:#04ba74;
    color:white;
    border: 1px solid #04ba74;
}

.flex-wrap{
    display:flex;
    flex-wrap:wrap;
}

.search-checklist-block{

}


#search-parameters > div{
    display:flex;
    flex-wrap:wrap;
    gap:30px;
}

#search-type{
    display:flex;
    flex-wrap:wrap;
    gap:5px;
    margin:0;
}

#search-parameters > div >div+div{
}



#search-discipline{
    display:flex;
    flex-wrap:wrap;
    gap:5px;
    margin:0;
}
#search-parameters label div{
    width:200px;
}

#search-parameters label{
    display:block;
}

#search-parameters ul{
    padding-left:0;
}
#search-parameters li{
    list-style:none;
    text-indent: 0;
}

.ui-autocomplete{
    position:absolute;
    z-index:100;
    background:white;
    border:1px solid lightgrey;
    list-style:none;
    padding:0;
    margin:0;
}

.ui-menu .ui-menu-item{
    margin:0;
    cursor:pointer;
}

.ui-menu .ui-menu-item-wrapper{
    position:relative;
    padding:3px 1em 3px .4em;
}

.message-box.share_menu{
    width: 580px;
}

.message-box.share_menu hr{
    margin: 20px;
    margin-left: 0;
    margin-right: 0;
}

.big-buttons-wrapper{
    display: flex;
    gap: 10px;
    margin: 20px;
    justify-content: center;
}

.big-button{
    border-radius: 10px;
    box-sizing: border-box;
    border: 1px solid #E9EBF2;
    padding: 20px;
    text-align: center;
    width: 220px;
    position: relative;
}

.big-button.disabled{
    box-shadow: unset;
    background: #E9EBF2;
    pointer: default;
    pointer-events: unset;
    color: #959699;
}

.big-button.disabled > .material-symbols-rounded{
    display: block;
    font-size: 36px;
    color: #959699;
}

.big-button > .material-symbols-rounded{
    display: block;
    font-size: 36px;
    color: #04BA74;
}

.big-button-title{
    font-size:  16px;
    line-height: 30px;
}

.big-button-description{
    color: grey;
    font-size: 10px;
    line-height: 14px;
}

.big-button.active{
    background: #EEFFF8;
    border: 1px solid #04BA74;
}

.public-link-button{
    border-radius: 10px;
    background: #04BA74;
    width: 100%;
    color: white;
    display: flex;
    gap: 20px;
    padding: 20px;
    box-sizing: border-box;
    align-items: center;
}

.public-link-icon{
    width: -moz-fit-content;
    width: fit-content;
}

.public-link-description{
    font-size: 12px;
}

.public-link-button.public-link-remove{
    margin-top: 5px;
    padding-top: 10px;
    padding-bottom: 10px;
}

.message-wrap.user-text .warning{
    font-size: 10px;
    gap: 4px;
    width: 220px;
    margin-left: 20px;
    text-align: center;
    justify-content: center;
}

.warning span{
    font-size: 10px;
}

.users-group{
    max-height: 124px;
    overflow-y: hidden;
}

.user-list{
    list-style:none;
    padding:0;
    margin:0;
    width:100%;
    display:flex;
    flex-wrap:wrap;
}

.user-label{
    padding:5px;
    border:1px solid #E9EBF2;
    position:relative;
    width:400px;
    display:flex;
    justify-content:space-between;
    overflow:hidden;
    margin-right:5px;
    margin-top:2px;
    margin-bottom:2px;
    border-radius:5px;
}

.user-list .user-label .workflow-delete-button{
    display:block;
    position:absolute;
    top:2px;
    right:2px;
}

.user-panel{
    padding-right:20px;
    vertical-align:top;
    border:none;
    display:inline-block;
    width:100%;
}

.user-label .window-close-button{
    top:2px;
    right:2px;
}

.user-name{
    font-size:14px;
    display: flex;
    align-items: center;
    gap: 8px;
    margin-bottom: 4px;
}

.user-name.collapsed-text-show-more{
    margin-top: 8px;
}

.user-name .material-symbols-rounded{
    color: grey;
    font-size: 16px;
}

.user-username{
    color:grey;
    font-size:12px;
    margin-top:4px;
    margin-left:8px;
}

.user-tag{
    padding: 3px;
    font-size: 12px;
    height: -moz-fit-content;
    height: fit-content;
    white-space: nowrap;
    padding-right: 6px;
    padding-left: 6px;
    border-radius: 4px;
    margin: 2px;
    display: inline-block;
    box-sizing: border-box;
}

.user-tag.permission-author{
    background-color: #3f4041;
    color: white;
}

.user-tag.permission-edit{
    background-color: #d3dae6;
}

.user-tag.permission-view{
    background-color: #e5eff8;
}

.user-tag.permission-comment{
    background-color: #e7ebf1;
}
.permission-select{
    
}

.export-jobs{
    width: -moz-fit-content;
    width: fit-content;
}

.export-item{
    width: 100%;
    border: 2px solid #04ba74;
    margin-bottom: 5px;
    border-radius: 5px;
    display: flex;
    align-items: center;
}

.window-close-button{
    right:8px;
    top:8px;
    position:absolute;
    cursor:pointer;
}

.window-close-button img{
    width:16px;
}

.screen-barrier{
    width:100%;
    height:100%;
    background:rgba(100,100,100,0.5);
    pointer-events:all;
    box-sizing: border-box;
    overflow: hidden;
    text-align: center;
    display: flex;
    justify-content: center;
    align-items: center;
}

.message-box{
    background:white;
    position:relative;
    box-shadow: 0px 2px 2px 0px rgba(0,0,0,0.3);
    border-radius:  15px;
    overflow: hidden;
    max-width: 1100px;
    width: 80%;
    height: 80%;
    max-height: -moz-fit-content;
    max-height: fit-content;
    box-sizing: border-box;
    padding-bottom: 50px;
}

.message-wrap .home-tabs{
    height: calc(100% - 100px);
    overflow-y: overlay;
}


.message-wrap{
    width:100%;
    height:100%;
    overflow-y: overlay;
    padding:20px;
    padding-left: 40px;
    padding-right: 40px;
    box-sizing:border-box;
    color:#444444;
    text-align: left;
}

.message-wrap > .window-close-button{
    right: 16px;
    top: 16px;
}

.message-wrap textarea, .message-wrap #project-discipline-input{
    resize: none;
    padding: 10px;
    border-radius: 3px;
    width: 100%;
    box-sizing: border-box;
    font-family: unset;
    border: 1px solid grey;
}

.discipline-tag{
    border-radius: 100px;
    background: #F4F4F4;
    padding: 6px 16px;
}

.disciplines-div{
    margin-bottom: 10px;
}

.ui-autocomplete{
    max-height: 200px;
    overflow-y: auto;
}

.user-text{
    font-size:14px;
}

.permission-select select{
    border:none;
    text-align: right;
}

.action-icon{
  cursor: pointer;
}
.drag-icon{
  cursor: grab;
}
.week-section{
  height: 100%;
}
#detail-workspace{
  height: 100%;
}
.node-section {
  width: 20%;
  background-color: #54C0DB;
  display: inline-block;
  height: 15vh;
  margin: 3%;
}
#outside-class-activity-section {

}
#teacher-class-activity-section {

}
#student-class-activity-section {

}

.node-block-grid{
    display: flex;
    flex-wrap: wrap;
    gap: 5px;
}

.overview-table td{
    padding: 5px;
    font-size: 12px;
}

.overview-table th{
    text-align: left;
    padding: 5px;
}

.overview-table .workflow-title{
    font-size: 12px;
}

.overview-table .table-user{
    font-weight: 600;
}


/* The popup form - hidden by default */
.form-popup {
  display: block;
  position: fixed;
  bottom: 0;
  right: 15px;
  border: 3px solid #f1f1f1;
  z-index: 9;
}

/* Add styles to the form container */
.form-container {
  max-width: 300px;
  padding: 10px;
  background-color: white;
}

.mdc-dialog__surface{
  width: 50vw;
}
text {
  pointer-events: none;
  fill: white;
}
#activity-title, #course-title, #program-title, .stategy-title, .week-title {
  font-size: 18px;
}
#activity-author, #course-author, #program-author, .week-author, .week-author  {
  font-size: 12px;
}
#activity-description, #course-description, #program-description, .week-description {
  font-size: 14px;
}
.component-completion-count, .node-completion-count{
  fill: rgb(172,184,191);
}
.activity-classification, .course-classification, .program-classification {
  font-size: 16px;
}
.sub-container {
    text-align:left;
    padding:20px;
    width: 40%;
    margin:40px;
    margin:40px;
    margin-left:5%;
    margin-right:0;
    padding-bottom:50px;
    vertical-align:top;
    display:inline-block;
    box-shadow: 0px 2px 2px 0px rgba(0,0,0,0.3);
    background:white;
    overflow:visible;
}


.body-wrapper{
    overflow: overlay;
    flex-grow: 1;
    height: 100%;
    position: relative;
}

.body-wrapper.printing{
    top:0px;
    left:0px;
    width:100%;
    height:100%;
    overflow:visible;
}

.splash-page{
    background:white;
    height:100%;
    width:100%;
    position:relative;
}

.splash-wrapper{
    position:absolute;
    left: calc(50% - 135px);
    top: calc(50% - 135px);
    padding:20px;
    transition:top 0.5s;
    text-align:center;
}

.splash-image-wrapper img{
    width:140px;
    padding:10px;
}

.splash-image-wrapper div{
    padding:10px;
    font-size:20px;
    color:#04ba74;
    white-space:nowrap;
}

.splash-image-wrapper{
    display:inline-block;
    width:240px;
    height:240px;
    vertical-align:middle;
    padding:20px;
    margin:10px;
    border-radius:20px;
    border:0px;
}

table tr.domain-row{
    background: #EEFFEE;
}
table tr.month-row{
    background: #99EE99;
}
table tr.year-row{
    background: #77CC77;
}
table tr.total-row{
    background: #55BB55;
}


.create-dropdown > .list-notification, .workflow-create-wrapper .list-notification{
    white-space: wrap;
    color: #444444;
    text-decoration: none;
    position: relative;
    padding-left: 20px;
    overflow: hidden;
    -webkit-line-clamp: 4;
    display: -webkit-box;
    -webkit-box-orient: vertical;
    max-width: 400px;
    white-space: normal;
    padding-bottom: 0px;
    padding-top: 0px;
    margin-bottom: 8px;
    margin-top: 8px;
}

.list-notification.unread::before, #notifications.unread::before{
    content: "";
    background-color: red;
    height: 6px;
    width: 6px;
    position: absolute;
    border-radius: 10px;
    left: 6px;
    top: calc(50% - 3px);
}

#notifications.unread::before{
    top: 0px;
    right: 6px;
    left: unset;
}

.list-notification .created-on{
    font-size: 12px;
    color: grey;
}

.comment-indicator.unread::after{
    content: "";
    background-color: red;
    height: 6px;
    width: 6px;
    position: absolute;
    border-radius: 10px;
    left: 0px;
    top: 0px;
}
.comment.unread::after{
    content: "";
    background-color: red;
    height: 6px;
    width: 6px;
    position: absolute;
    border-radius: 10px;
    right: 2px;
    top: calc(50% - 3px);
}

.comment-tag-box{
    position: absolute;
    z-index: 10;
    right: -200px;
    max-width: 200px;
    background: white;
    border-radius: 5px;
    border: 1px solid #04ba74;
}

#user-feedback{
    margin-top: auto;
}

#user-feedback-app {
  bottom: 0px;
  display: inline;
  right: 8px;
  position: absolute;
  text-align: left;
}

/*
User feedback app; this can be factored out to its own file and loaded
last to avoid need for !important
*/
#user-feedback-component .mdc-icon-button {
  transform: translate(6px, -3px);
}
#user-feedback-component  .mdc-icon-button:after {
  background-color: white!important;
}
#user-feedback-component  .mdc-icon-button:before {
  background-color: white!important;
}
#user-feedback-component  .mdc-icon-button:hover:before {
  opacity: 0.25 !important;
}
#user-feedback-component  .mdc-icon-button.mdc-ripple-upgraded:before {
  height: 25px!important;
  left: 12px!important;
  top: 12px!important;
  width: 25px!important;
}
#user-feedback-component  .mdc-icon-button.mdc-ripple-upgraded:after {
  height: 25px!important;
  left: 12px!important;
  top: 12px!important;
  width: 25px!important;
}
#user-feedback-component  .mdc-icon-button__icon {
  vertical-align: baseline;
}
#user-feedback-component  .mdc-menu__items {
  font-size: 14px !important;
}
#user-feedback-component  .mdc-button {
  font-weight: bold !important;
}
#user-feedback-component  .mdc-button:not(:disabled) {
  color: var(--mdc-theme-secondary) !important;
}
#user-feedback-component  .mdc-button:disabled {
  color: rgba(0,0,0,.37) !important;
}
#user-feedback-component  .mdc-text-field--focused:not(.mdc-text-field--disabled) .mdc-floating-label {
  color: var(--mdc-theme-primary) !important;
}
#user-feedback-component  .mdc-text-field--focused:not(.mdc-text-field--disabled) .mdc-floating-label :not(i) {
  font-family: inherit;
}

.flatpickr-calendar {
  background: transparent;
  opacity: 0;
  display: none;
  text-align: center;
  visibility: hidden;
  padding: 0;
  -webkit-animation: none;
          animation: none;
  direction: ltr;
  border: 0;
  font-size: 14px;
  line-height: 24px;
  border-radius: 5px;
  position: absolute;
  width: 307.875px;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  -ms-touch-action: manipulation;
      touch-action: manipulation;
  background: #fff;
  -webkit-box-shadow: 1px 0 0 #e6e6e6, -1px 0 0 #e6e6e6, 0 1px 0 #e6e6e6, 0 -1px 0 #e6e6e6, 0 3px 13px rgba(0,0,0,0.08);
          box-shadow: 1px 0 0 #e6e6e6, -1px 0 0 #e6e6e6, 0 1px 0 #e6e6e6, 0 -1px 0 #e6e6e6, 0 3px 13px rgba(0,0,0,0.08);
}
.flatpickr-calendar.open,
.flatpickr-calendar.inline {
  opacity: 1;
  max-height: 640px;
  visibility: visible;
}
.flatpickr-calendar.open {
  display: inline-block;
  z-index: 99999;
}
.flatpickr-calendar.animate.open {
  -webkit-animation: fpFadeInDown 300ms cubic-bezier(0.23, 1, 0.32, 1);
          animation: fpFadeInDown 300ms cubic-bezier(0.23, 1, 0.32, 1);
}
.flatpickr-calendar.inline {
  display: block;
  position: relative;
  top: 2px;
}
.flatpickr-calendar.static {
  position: absolute;
  top: calc(100% + 2px);
}
.flatpickr-calendar.static.open {
  z-index: 999;
  display: block;
}
.flatpickr-calendar.multiMonth .flatpickr-days .dayContainer:nth-child(n+1) .flatpickr-day.inRange:nth-child(7n+7) {
  -webkit-box-shadow: none !important;
          box-shadow: none !important;
}
.flatpickr-calendar.multiMonth .flatpickr-days .dayContainer:nth-child(n+2) .flatpickr-day.inRange:nth-child(7n+1) {
  -webkit-box-shadow: -2px 0 0 #e6e6e6, 5px 0 0 #e6e6e6;
          box-shadow: -2px 0 0 #e6e6e6, 5px 0 0 #e6e6e6;
}
.flatpickr-calendar .hasWeeks .dayContainer,
.flatpickr-calendar .hasTime .dayContainer {
  border-bottom: 0;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.flatpickr-calendar .hasWeeks .dayContainer {
  border-left: 0;
}
.flatpickr-calendar.hasTime .flatpickr-time {
  height: 40px;
  border-top: 1px solid #e6e6e6;
}
.flatpickr-calendar.noCalendar.hasTime .flatpickr-time {
  height: auto;
}
.flatpickr-calendar:before,
.flatpickr-calendar:after {
  position: absolute;
  display: block;
  pointer-events: none;
  border: solid transparent;
  content: '';
  height: 0;
  width: 0;
  left: 22px;
}
.flatpickr-calendar.rightMost:before,
.flatpickr-calendar.arrowRight:before,
.flatpickr-calendar.rightMost:after,
.flatpickr-calendar.arrowRight:after {
  left: auto;
  right: 22px;
}
.flatpickr-calendar.arrowCenter:before,
.flatpickr-calendar.arrowCenter:after {
  left: 50%;
  right: 50%;
}
.flatpickr-calendar:before {
  border-width: 5px;
  margin: 0 -5px;
}
.flatpickr-calendar:after {
  border-width: 4px;
  margin: 0 -4px;
}
.flatpickr-calendar.arrowTop:before,
.flatpickr-calendar.arrowTop:after {
  bottom: 100%;
}
.flatpickr-calendar.arrowTop:before {
  border-bottom-color: #e6e6e6;
}
.flatpickr-calendar.arrowTop:after {
  border-bottom-color: #fff;
}
.flatpickr-calendar.arrowBottom:before,
.flatpickr-calendar.arrowBottom:after {
  top: 100%;
}
.flatpickr-calendar.arrowBottom:before {
  border-top-color: #e6e6e6;
}
.flatpickr-calendar.arrowBottom:after {
  border-top-color: #fff;
}
.flatpickr-calendar:focus {
  outline: 0;
}
.flatpickr-wrapper {
  position: relative;
  display: inline-block;
}
.flatpickr-months {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}
.flatpickr-months .flatpickr-month {
  background: transparent;
  color: rgba(0,0,0,0.9);
  fill: rgba(0,0,0,0.9);
  height: 34px;
  line-height: 1;
  text-align: center;
  position: relative;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  overflow: hidden;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
      -ms-flex: 1;
          flex: 1;
}
.flatpickr-months .flatpickr-prev-month,
.flatpickr-months .flatpickr-next-month {
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  text-decoration: none;
  cursor: pointer;
  position: absolute;
  top: 0;
  height: 34px;
  padding: 10px;
  z-index: 3;
  color: rgba(0,0,0,0.9);
  fill: rgba(0,0,0,0.9);
}
.flatpickr-months .flatpickr-prev-month.flatpickr-disabled,
.flatpickr-months .flatpickr-next-month.flatpickr-disabled {
  display: none;
}
.flatpickr-months .flatpickr-prev-month i,
.flatpickr-months .flatpickr-next-month i {
  position: relative;
}
.flatpickr-months .flatpickr-prev-month.flatpickr-prev-month,
.flatpickr-months .flatpickr-next-month.flatpickr-prev-month {
/*
      /*rtl:begin:ignore*/
/*
      */
  left: 0;
/*
      /*rtl:end:ignore*/
/*
      */
}
/*
      /*rtl:begin:ignore*/
/*
      /*rtl:end:ignore*/
.flatpickr-months .flatpickr-prev-month.flatpickr-next-month,
.flatpickr-months .flatpickr-next-month.flatpickr-next-month {
/*
      /*rtl:begin:ignore*/
/*
      */
  right: 0;
/*
      /*rtl:end:ignore*/
/*
      */
}
/*
      /*rtl:begin:ignore*/
/*
      /*rtl:end:ignore*/
.flatpickr-months .flatpickr-prev-month:hover,
.flatpickr-months .flatpickr-next-month:hover {
  color: #959ea9;
}
.flatpickr-months .flatpickr-prev-month:hover svg,
.flatpickr-months .flatpickr-next-month:hover svg {
  fill: #f64747;
}
.flatpickr-months .flatpickr-prev-month svg,
.flatpickr-months .flatpickr-next-month svg {
  width: 14px;
  height: 14px;
}
.flatpickr-months .flatpickr-prev-month svg path,
.flatpickr-months .flatpickr-next-month svg path {
  -webkit-transition: fill 0.1s;
  transition: fill 0.1s;
  fill: inherit;
}
.numInputWrapper {
  position: relative;
  height: auto;
}
.numInputWrapper input,
.numInputWrapper span {
  display: inline-block;
}
.numInputWrapper input {
  width: 100%;
}
.numInputWrapper input::-ms-clear {
  display: none;
}
.numInputWrapper input::-webkit-outer-spin-button,
.numInputWrapper input::-webkit-inner-spin-button {
  margin: 0;
  -webkit-appearance: none;
}
.numInputWrapper span {
  position: absolute;
  right: 0;
  width: 14px;
  padding: 0 4px 0 2px;
  height: 50%;
  line-height: 50%;
  opacity: 0;
  cursor: pointer;
  border: 1px solid rgba(57,57,57,0.15);
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
}
.numInputWrapper span:hover {
  background: rgba(0,0,0,0.1);
}
.numInputWrapper span:active {
  background: rgba(0,0,0,0.2);
}
.numInputWrapper span:after {
  display: block;
  content: "";
  position: absolute;
}
.numInputWrapper span.arrowUp {
  top: 0;
  border-bottom: 0;
}
.numInputWrapper span.arrowUp:after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-bottom: 4px solid rgba(57,57,57,0.6);
  top: 26%;
}
.numInputWrapper span.arrowDown {
  top: 50%;
}
.numInputWrapper span.arrowDown:after {
  border-left: 4px solid transparent;
  border-right: 4px solid transparent;
  border-top: 4px solid rgba(57,57,57,0.6);
  top: 40%;
}
.numInputWrapper span svg {
  width: inherit;
  height: auto;
}
.numInputWrapper span svg path {
  fill: rgba(0,0,0,0.5);
}
.numInputWrapper:hover {
  background: rgba(0,0,0,0.05);
}
.numInputWrapper:hover span {
  opacity: 1;
}
.flatpickr-current-month {
  font-size: 135%;
  line-height: inherit;
  font-weight: 300;
  color: inherit;
  position: absolute;
  width: 75%;
  left: 12.5%;
  padding: 7.48px 0 0 0;
  line-height: 1;
  height: 34px;
  display: inline-block;
  text-align: center;
  -webkit-transform: translate3d(0px, 0px, 0px);
          transform: translate3d(0px, 0px, 0px);
}
.flatpickr-current-month span.cur-month {
  font-family: inherit;
  font-weight: 700;
  color: inherit;
  display: inline-block;
  margin-left: 0.5ch;
  padding: 0;
}
.flatpickr-current-month span.cur-month:hover {
  background: rgba(0,0,0,0.05);
}
.flatpickr-current-month .numInputWrapper {
  width: 6ch;
  width: 7ch\0;
  display: inline-block;
}
.flatpickr-current-month .numInputWrapper span.arrowUp:after {
  border-bottom-color: rgba(0,0,0,0.9);
}
.flatpickr-current-month .numInputWrapper span.arrowDown:after {
  border-top-color: rgba(0,0,0,0.9);
}
.flatpickr-current-month input.cur-year {
  background: transparent;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  color: inherit;
  cursor: text;
  padding: 0 0 0 0.5ch;
  margin: 0;
  display: inline-block;
  font-size: inherit;
  font-family: inherit;
  font-weight: 300;
  line-height: inherit;
  height: auto;
  border: 0;
  border-radius: 0;
  vertical-align: initial;
  -webkit-appearance: textfield;
  -moz-appearance: textfield;
  appearance: textfield;
}
.flatpickr-current-month input.cur-year:focus {
  outline: 0;
}
.flatpickr-current-month input.cur-year[disabled],
.flatpickr-current-month input.cur-year[disabled]:hover {
  font-size: 100%;
  color: rgba(0,0,0,0.5);
  background: transparent;
  pointer-events: none;
}
.flatpickr-current-month .flatpickr-monthDropdown-months {
  appearance: menulist;
  background: transparent;
  border: none;
  border-radius: 0;
  box-sizing: border-box;
  color: inherit;
  cursor: pointer;
  font-size: inherit;
  font-family: inherit;
  font-weight: 300;
  height: auto;
  line-height: inherit;
  margin: -1px 0 0 0;
  outline: none;
  padding: 0 0 0 0.5ch;
  position: relative;
  vertical-align: initial;
  -webkit-box-sizing: border-box;
  -webkit-appearance: menulist;
  -moz-appearance: menulist;
  width: auto;
}
.flatpickr-current-month .flatpickr-monthDropdown-months:focus,
.flatpickr-current-month .flatpickr-monthDropdown-months:active {
  outline: none;
}
.flatpickr-current-month .flatpickr-monthDropdown-months:hover {
  background: rgba(0,0,0,0.05);
}
.flatpickr-current-month .flatpickr-monthDropdown-months .flatpickr-monthDropdown-month {
  background-color: transparent;
  outline: none;
  padding: 0;
}
.flatpickr-weekdays {
  background: transparent;
  text-align: center;
  overflow: hidden;
  width: 100%;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
  -webkit-align-items: center;
      -ms-flex-align: center;
          align-items: center;
  height: 28px;
}
.flatpickr-weekdays .flatpickr-weekdaycontainer {
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
      -ms-flex: 1;
          flex: 1;
}
span.flatpickr-weekday {
  cursor: default;
  font-size: 90%;
  background: transparent;
  color: rgba(0,0,0,0.54);
  line-height: 1;
  margin: 0;
  text-align: center;
  display: block;
  -webkit-box-flex: 1;
  -webkit-flex: 1;
      -ms-flex: 1;
          flex: 1;
  font-weight: bolder;
}
.dayContainer,
.flatpickr-weeks {
  padding: 1px 0 0 0;
}
.flatpickr-days {
  position: relative;
  overflow: hidden;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: start;
  -webkit-align-items: flex-start;
      -ms-flex-align: start;
          align-items: flex-start;
  width: 307.875px;
}
.flatpickr-days:focus {
  outline: 0;
}
.dayContainer {
  padding: 0;
  outline: 0;
  text-align: left;
  width: 307.875px;
  min-width: 307.875px;
  max-width: 307.875px;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  display: inline-block;
  display: -ms-flexbox;
  display: -webkit-box;
  display: -webkit-flex;
  display: flex;
  -webkit-flex-wrap: wrap;
          flex-wrap: wrap;
  -ms-flex-wrap: wrap;
  -ms-flex-pack: justify;
  -webkit-justify-content: space-around;
          justify-content: space-around;
  -webkit-transform: translate3d(0px, 0px, 0px);
          transform: translate3d(0px, 0px, 0px);
  opacity: 1;
}
.dayContainer + .dayContainer {
  -webkit-box-shadow: -1px 0 0 #e6e6e6;
          box-shadow: -1px 0 0 #e6e6e6;
}
.flatpickr-day {
  background: none;
  border: 1px solid transparent;
  border-radius: 150px;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  color: #393939;
  cursor: pointer;
  font-weight: 400;
  width: 14.2857143%;
  -webkit-flex-basis: 14.2857143%;
      -ms-flex-preferred-size: 14.2857143%;
          flex-basis: 14.2857143%;
  max-width: 39px;
  height: 39px;
  line-height: 39px;
  margin: 0;
  display: inline-block;
  position: relative;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
      -ms-flex-pack: center;
          justify-content: center;
  text-align: center;
}
.flatpickr-day.inRange,
.flatpickr-day.prevMonthDay.inRange,
.flatpickr-day.nextMonthDay.inRange,
.flatpickr-day.today.inRange,
.flatpickr-day.prevMonthDay.today.inRange,
.flatpickr-day.nextMonthDay.today.inRange,
.flatpickr-day:hover,
.flatpickr-day.prevMonthDay:hover,
.flatpickr-day.nextMonthDay:hover,
.flatpickr-day:focus,
.flatpickr-day.prevMonthDay:focus,
.flatpickr-day.nextMonthDay:focus {
  cursor: pointer;
  outline: 0;
  background: #e6e6e6;
  border-color: #e6e6e6;
}
.flatpickr-day.today {
  border-color: #959ea9;
}
.flatpickr-day.today:hover,
.flatpickr-day.today:focus {
  border-color: #959ea9;
  background: #959ea9;
  color: #fff;
}
.flatpickr-day.selected,
.flatpickr-day.startRange,
.flatpickr-day.endRange,
.flatpickr-day.selected.inRange,
.flatpickr-day.startRange.inRange,
.flatpickr-day.endRange.inRange,
.flatpickr-day.selected:focus,
.flatpickr-day.startRange:focus,
.flatpickr-day.endRange:focus,
.flatpickr-day.selected:hover,
.flatpickr-day.startRange:hover,
.flatpickr-day.endRange:hover,
.flatpickr-day.selected.prevMonthDay,
.flatpickr-day.startRange.prevMonthDay,
.flatpickr-day.endRange.prevMonthDay,
.flatpickr-day.selected.nextMonthDay,
.flatpickr-day.startRange.nextMonthDay,
.flatpickr-day.endRange.nextMonthDay {
  background: #569ff7;
  -webkit-box-shadow: none;
          box-shadow: none;
  color: #fff;
  border-color: #569ff7;
}
.flatpickr-day.selected.startRange,
.flatpickr-day.startRange.startRange,
.flatpickr-day.endRange.startRange {
  border-radius: 50px 0 0 50px;
}
.flatpickr-day.selected.endRange,
.flatpickr-day.startRange.endRange,
.flatpickr-day.endRange.endRange {
  border-radius: 0 50px 50px 0;
}
.flatpickr-day.selected.startRange + .endRange:not(:nth-child(7n+1)),
.flatpickr-day.startRange.startRange + .endRange:not(:nth-child(7n+1)),
.flatpickr-day.endRange.startRange + .endRange:not(:nth-child(7n+1)) {
  -webkit-box-shadow: -10px 0 0 #569ff7;
          box-shadow: -10px 0 0 #569ff7;
}
.flatpickr-day.selected.startRange.endRange,
.flatpickr-day.startRange.startRange.endRange,
.flatpickr-day.endRange.startRange.endRange {
  border-radius: 50px;
}
.flatpickr-day.inRange {
  border-radius: 0;
  -webkit-box-shadow: -5px 0 0 #e6e6e6, 5px 0 0 #e6e6e6;
          box-shadow: -5px 0 0 #e6e6e6, 5px 0 0 #e6e6e6;
}
.flatpickr-day.flatpickr-disabled,
.flatpickr-day.flatpickr-disabled:hover,
.flatpickr-day.prevMonthDay,
.flatpickr-day.nextMonthDay,
.flatpickr-day.notAllowed,
.flatpickr-day.notAllowed.prevMonthDay,
.flatpickr-day.notAllowed.nextMonthDay {
  color: rgba(57,57,57,0.3);
  background: transparent;
  border-color: transparent;
  cursor: default;
}
.flatpickr-day.flatpickr-disabled,
.flatpickr-day.flatpickr-disabled:hover {
  cursor: not-allowed;
  color: rgba(57,57,57,0.1);
}
.flatpickr-day.week.selected {
  border-radius: 0;
  -webkit-box-shadow: -5px 0 0 #569ff7, 5px 0 0 #569ff7;
          box-shadow: -5px 0 0 #569ff7, 5px 0 0 #569ff7;
}
.flatpickr-day.hidden {
  visibility: hidden;
}
.rangeMode .flatpickr-day {
  margin-top: 1px;
}
.flatpickr-weekwrapper {
  float: left;
}
.flatpickr-weekwrapper .flatpickr-weeks {
  padding: 0 12px;
  -webkit-box-shadow: 1px 0 0 #e6e6e6;
          box-shadow: 1px 0 0 #e6e6e6;
}
.flatpickr-weekwrapper .flatpickr-weekday {
  float: none;
  width: 100%;
  line-height: 28px;
}
.flatpickr-weekwrapper span.flatpickr-day,
.flatpickr-weekwrapper span.flatpickr-day:hover {
  display: block;
  width: 100%;
  max-width: none;
  color: rgba(57,57,57,0.3);
  background: transparent;
  cursor: default;
  border: none;
}
.flatpickr-innerContainer {
  display: block;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  overflow: hidden;
}
.flatpickr-rContainer {
  display: inline-block;
  padding: 0;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
}
.flatpickr-time {
  text-align: center;
  outline: 0;
  display: block;
  height: 0;
  line-height: 40px;
  max-height: 40px;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  overflow: hidden;
  display: -webkit-box;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
}
.flatpickr-time:after {
  content: "";
  display: table;
  clear: both;
}
.flatpickr-time .numInputWrapper {
  -webkit-box-flex: 1;
  -webkit-flex: 1;
      -ms-flex: 1;
          flex: 1;
  width: 40%;
  height: 40px;
  float: left;
}
.flatpickr-time .numInputWrapper span.arrowUp:after {
  border-bottom-color: #393939;
}
.flatpickr-time .numInputWrapper span.arrowDown:after {
  border-top-color: #393939;
}
.flatpickr-time.hasSeconds .numInputWrapper {
  width: 26%;
}
.flatpickr-time.time24hr .numInputWrapper {
  width: 49%;
}
.flatpickr-time input {
  background: transparent;
  -webkit-box-shadow: none;
          box-shadow: none;
  border: 0;
  border-radius: 0;
  text-align: center;
  margin: 0;
  padding: 0;
  height: inherit;
  line-height: inherit;
  color: #393939;
  font-size: 14px;
  position: relative;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  -webkit-appearance: textfield;
  -moz-appearance: textfield;
  appearance: textfield;
}
.flatpickr-time input.flatpickr-hour {
  font-weight: bold;
}
.flatpickr-time input.flatpickr-minute,
.flatpickr-time input.flatpickr-second {
  font-weight: 400;
}
.flatpickr-time input:focus {
  outline: 0;
  border: 0;
}
.flatpickr-time .flatpickr-time-separator,
.flatpickr-time .flatpickr-am-pm {
  height: inherit;
  float: left;
  line-height: inherit;
  color: #393939;
  font-weight: bold;
  width: 2%;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
  -webkit-align-self: center;
      -ms-flex-item-align: center;
          align-self: center;
}
.flatpickr-time .flatpickr-am-pm {
  outline: 0;
  width: 18%;
  cursor: pointer;
  text-align: center;
  font-weight: 400;
}
.flatpickr-time input:hover,
.flatpickr-time .flatpickr-am-pm:hover,
.flatpickr-time input:focus,
.flatpickr-time .flatpickr-am-pm:focus {
  background: #eee;
}
.flatpickr-input[readonly] {
  cursor: pointer;
}
@-webkit-keyframes fpFadeInDown {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -20px, 0);
            transform: translate3d(0, -20px, 0);
  }
  to {
    opacity: 1;
    -webkit-transform: translate3d(0, 0, 0);
            transform: translate3d(0, 0, 0);
  }
}
@keyframes fpFadeInDown {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -20px, 0);
            transform: translate3d(0, -20px, 0);
  }
  to {
    opacity: 1;
    -webkit-transform: translate3d(0, 0, 0);
            transform: translate3d(0, 0, 0);
  }
}
